@@ -20,81 +20,13 @@
 
 /* Driver file for Barrel */
 
-/*-
-  Version 7: 03/11/15 X/Windows
-*/
-
-#include "file.h"
-#ifdef WINVER
-#include "BarrelP.h"
-#define TITLE "wbarrel"
-
-static BarrelRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->barrel.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#include <Xm/ToggleB.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Barrel.h"
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/barrel.t.xpm"
-#include "pixmaps/barrel.p.xpm"
-#include "pixmaps/barrel.s.xpm"
-#include "pixmaps/barrel.m.xpm"
-#include "pixmaps/barrel.l.xpm"
-#include "pixmaps/barrel.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?barrel_t_xpm:barrel_p_xpm):\
-(((s)<=24)?barrel_s_xpm:barrel_m_xpm)):\
-(((s)<=48)?barrel_l_xpm:barrel_xpm))
-#endif
-#include "pixmaps/barrel.xbm"
-#define DEFINE_XBM (char *) barrel_bits, barrel_width, barrel_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Barrel Version 7.4\n"
+"Barrel Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -107,7 +39,7 @@ static const char optionsHelp[] = {
 "[-bumpSound {filename}] [-moveSound {filename}]\n"
 "[-{font|fn} {fontname}] [-[no]orient] [-[no]pairs]\n"
 "[-base {int}] [-userName {string}] [-scoreFile {filename}]\n"
-"[-scores] [-version]\n"
+"[-scores] [-version]"
 };
 #endif
 
@@ -121,7 +53,7 @@ static const char descriptionHelp[] = {
 "three of the long rows left and right.  Two of the plungers\n"
 "sit together and the other (the middle plunger) is "
 "separate from the other two.  There are 2 separate wheels or\n"
-"disks that rotate about the center axis.\n"
+"disks that rotate about the center axis."
 };
 
 static const char featuresHelp[] = {
@@ -178,7 +110,7 @@ static const char featuresHelp[] = {
 "  2    Down\n"
 "\n"
 "Use the shift key and the up or down arrow keys to rotate "
-"all the tiles.\n"
+"all the tiles."
 };
 
 static const char referencesHelp[] = {
@@ -189,14 +121,87 @@ static const char referencesHelp[] = {
 "Bantam Books, New York, November 1981, pp 25-42.\n"
 "John Ewing & Czes Kosniowski, Puzzle it Out: "
 "Cubes Groups and Puzzles, Cambridge University Press,\n"
-"New York, 1982, pp 50-54?\n"
+"New York, 1982, pp 50-54?"
 };
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, only implemented when oriented is off.\n"
+"Auto-solver: sorry, only implemented when oriented is off."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "BarrelP.h"
+#define TITLE "wbarrel"
+
+static BarrelRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->barrel.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#include <Xm/ToggleB.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Barrel.h"
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "barrel.t.xpm"
+#include "barrel.p.xpm"
+#include "barrel.s.xpm"
+#include "barrel.m.xpm"
+#include "barrel.l.xpm"
+#include "barrel.xpm"
+#else
+#include "pixmaps/barrel.t.xpm"
+#include "pixmaps/barrel.p.xpm"
+#include "pixmaps/barrel.s.xpm"
+#include "pixmaps/barrel.m.xpm"
+#include "pixmaps/barrel.l.xpm"
+#include "pixmaps/barrel.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?barrel_t_xpm:barrel_p_xpm):\
+(((s)<=24)?barrel_s_xpm:barrel_m_xpm)):\
+(((s)<=48)?barrel_l_xpm:barrel_xpm)))
+#endif
+#include "pixmaps/barrel.xbm"
+#define DEFINE_XBM (char *) barrel_bits, barrel_width, barrel_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "barrel.scores"
 #endif
@@ -503,7 +508,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -1157,6 +1162,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1391,7 +1397,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1417,7 +1423,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1564,7 +1570,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
