@@ -20,76 +20,13 @@
 
 /* Driver file for Cubes */
 
-#include "file.h"
-#ifdef WINVER
-#include "CubesP.h"
-#define TITLE "wcubes"
-
-static CubesRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->cubes.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Cubes.h"
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/cubes.t.xpm"
-#include "pixmaps/cubes.p.xpm"
-#include "pixmaps/cubes.s.xpm"
-#include "pixmaps/cubes.m.xpm"
-#include "pixmaps/cubes.l.xpm"
-#include "pixmaps/cubes.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?cubes_t_xpm:cubes_p_xpm):\
-(((s)<=24)?cubes_s_xpm:cubes_m_xpm)):\
-(((s)<=48)?cubes_l_xpm:cubes_xpm))
-#endif
-#include "pixmaps/cubes.xbm"
-#define DEFINE_XBM (char *) cubes_bits, cubes_width, cubes_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Cubes Version 7.4\n"
+"Cubes Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -101,7 +38,7 @@ static const char optionsHelp[] = {
 "[-bumpSound {filename}] [-dripSound {filename}]\n"
 "[-{font|fn} {fontname}] [-size{x|y|z} {int}] [-base {int}]\n"
 "[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-"[-version]\n"
+"[-version]"
 };
 #endif
 
@@ -116,7 +53,7 @@ static const char descriptionHelp[] = {
 "soon after.)  Similar 3D puzzles include  BloxBox; "
 "Qrazy Qube (2x2x2) by P. Hein of Denmark and Varikon Box 'L\n"
 "Box 'L (3x3x3) (Hungary) and Mad Marbles (3x3x3) by "
-"Toys & Games International USA.\n"
+"Toys & Games International USA."
 };
 
 static const char featuresHelp[] = {
@@ -172,7 +109,7 @@ static const char featuresHelp[] = {
 "\n"
 "The control key allows you to change the complexity of "
 "xcubes.  Hold down control key and use the keypad\n"
-"or arrow keys to reduce or enlarge puzzle complexity.\n"
+"or arrow keys to reduce or enlarge puzzle complexity."
 };
 
 static const char referencesHelp[] = {
@@ -181,15 +118,87 @@ static const char referencesHelp[] = {
 "pp 1, 157-159.\n"
 "Jerry Slocum & Jack Botermans, Puzzles Old & New (How to Make "
 "and Solve Them),  University of Washington\n"
-"Press, Seattle 1987, p 126, 127.\n"
+"Press, Seattle 1987, p 126, 127."
 };
 #endif
 
 static const char solveHelp[] = {
 "Auto-solver: sorry, only implemented for lxmx1 where "
-"l > 3 and m > 3.\n"
+"l > 3 and m > 3."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "CubesP.h"
+#define TITLE "wcubes"
+
+static CubesRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->cubes.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Cubes.h"
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "cubes.t.xpm"
+#include "cubes.p.xpm"
+#include "cubes.s.xpm"
+#include "cubes.m.xpm"
+#include "cubes.l.xpm"
+#include "cubes.xpm"
+#else
+#include "pixmaps/cubes.t.xpm"
+#include "pixmaps/cubes.p.xpm"
+#include "pixmaps/cubes.s.xpm"
+#include "pixmaps/cubes.m.xpm"
+#include "pixmaps/cubes.l.xpm"
+#include "pixmaps/cubes.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?cubes_t_xpm:cubes_p_xpm):\
+(((s)<=24)?cubes_s_xpm:cubes_m_xpm)):\
+(((s)<=48)?cubes_l_xpm:cubes_xpm)))
+#endif
+#include "pixmaps/cubes.xbm"
+#define DEFINE_XBM (char *) cubes_bits, cubes_width, cubes_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "cubes.scores"
 #endif
@@ -531,7 +540,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -1105,6 +1114,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1254,7 +1264,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1280,7 +1290,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1416,7 +1426,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
