@@ -20,82 +20,13 @@
 
 /* Driver file for Dino */
 
-#include "file.h"
-#ifdef WINVER
-#include "DinoP.h"
-#define TITLE "wdino"
-
-static DinoRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->dino.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/ToggleB.h>
-#include <Xm/ToggleBG.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Dino.h"
-#include "Dino2d.h"
-#include "Dino3d.h"
-#ifdef HAVE_OPENGL
-#include "DinoGL.h"
-#endif
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/dino.t.xpm"
-#include "pixmaps/dino.p.xpm"
-#include "pixmaps/dino.s.xpm"
-#include "pixmaps/dino.m.xpm"
-#include "pixmaps/dino.l.xpm"
-#include "pixmaps/dino.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?dino_t_xpm:dino_p_xpm):\
-(((s)<=24)?dino_s_xpm:dino_m_xpm)):\
-(((s)<=48)?dino_l_xpm:dino_xpm))
-#endif
-#include "pixmaps/dino.xbm"
-#define DEFINE_XBM (char *) dino_bits, dino_width, dino_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Dino Version 7.4\n"
+"Dino Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -107,7 +38,7 @@ static const char optionsHelp[] = {
 "[-{font|fn} {fontname}] [-view {int}]\n"
 "[-{mode {int} | both}] [-[no]orient] [-[no]practice]\n"
 "[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-"[-version]\n"
+"[-version]"
 };
 #endif
 
@@ -122,7 +53,7 @@ static const char descriptionHelp[] = {
 "6 Colors with solid colors, (a 4 color and a 2 color "
 "are also available with point oriented coloring))\n"
 "manufactured by The International Puzzle & Games "
-"(Great Animation International Corporation).\n"
+"(Great Animation International Corporation)."
 };
 
 static const char featuresHelp[] = {
@@ -205,18 +136,96 @@ static const char featuresHelp[] = {
 "\n"
 "Use the control key and the left mouse button, keypad, or "
 "arrow keys to move the whole cube.  This is\n"
-"not recorded as a turn.\n"
+"not recorded as a turn."
 };
 
 static const char referencesHelp[] = {
-"International Puzzles & Games Catalog.\n"
+"International Puzzles & Games Catalog."
 };
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "DinoP.h"
+#define TITLE "wdino"
+
+static DinoRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->dino.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/ToggleB.h>
+#include <Xm/ToggleBG.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Dino.h"
+#include "Dino2d.h"
+#include "Dino3d.h"
+#ifdef HAVE_OPENGL
+#include "DinoGL.h"
+#endif
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "dino.t.xpm"
+#include "dino.p.xpm"
+#include "dino.s.xpm"
+#include "dino.m.xpm"
+#include "dino.l.xpm"
+#include "dino.xpm"
+#else
+#include "pixmaps/dino.t.xpm"
+#include "pixmaps/dino.p.xpm"
+#include "pixmaps/dino.s.xpm"
+#include "pixmaps/dino.m.xpm"
+#include "pixmaps/dino.l.xpm"
+#include "pixmaps/dino.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?dino_t_xpm:dino_p_xpm):\
+(((s)<=24)?dino_s_xpm:dino_m_xpm)):\
+(((s)<=48)?dino_l_xpm:dino_xpm)))
+#endif
+#include "pixmaps/dino.xbm"
+#define DEFINE_XBM (char *) dino_bits, dino_width, dino_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "dino.scores"
 #endif
@@ -478,7 +487,7 @@ makeEquivalent(String *userName, String *scoreFile, int *mode,
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(*scoreFile, ""))
@@ -1533,6 +1542,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1701,7 +1711,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1727,7 +1737,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
