@@ -20,77 +20,13 @@
 
 /* Driver file for Hexagons */
 
-#include "file.h"
-#ifdef WINVER
-#include "HexagonsP.h"
-#define TITLE "whexagons"
-
-static HexagonsRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->hexagons.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#include <Xm/ToggleB.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Hexagons.h"
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/hexagons.t.xpm"
-#include "pixmaps/hexagons.p.xpm"
-#include "pixmaps/hexagons.s.xpm"
-#include "pixmaps/hexagons.m.xpm"
-#include "pixmaps/hexagons.l.xpm"
-#include "pixmaps/hexagons.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?hexagons_t_xpm:hexagons_p_xpm):\
-(((s)<=24)?hexagons_s_xpm:hexagons_m_xpm)):\
-(((s)<=48)?hexagons_l_xpm:hexagons_xpm))
-#endif
-#include "pixmaps/hexagons.xbm"
-#define DEFINE_XBM (char *) hexagons_bits, hexagons_width, hexagons_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Hexagons Version 7.4\n"
+"Hexagons Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -101,7 +37,7 @@ static const char optionsHelp[] = {
 "[-[no]sound] [-bumpSound {filename}]\n"
 "[-{font|fn} {fontname}] [-size{x|y} {int}] [-[no]corners]\n"
 "[-base {int}] [-userName {string}] [-scoreFile {filename}]\n"
-"[-scores] [-version]\n"
+"[-scores] [-version]"
 };
 #endif
 
@@ -117,7 +53,7 @@ static const char descriptionHelp[] = {
 "Bernhard Wiezorke came up with the similar 17 \n"
 "puzzle, \"Hexafax, the New Fifteen Puzzle\", in 1991 and a "
 "smaller 11 piece \"Counterfax\" of which 8 were\n"
-"numbered.\n"
+"numbered."
 };
 
 static const char featuresHelp[] = {
@@ -170,7 +106,7 @@ static const char featuresHelp[] = {
 "\n"
 "The control key allows you to change the complexity of "
 "xhexagons.  Hold down control key and use the keypad\n"
-"or arrow keys to reduce or enlarge puzzle complexity.\n"
+"or arrow keys to reduce or enlarge puzzle complexity."
 };
 
 static const char referencesHelp[] = {
@@ -181,14 +117,87 @@ static const char referencesHelp[] = {
 "Dieter Gebhardt, \"Ninefield Revisited\", CFF 58, "
 "July 2002, p 21.\n"
 "Bernhard Wiezorke, \"Hexafax, the New Fifteen Puzzle\" "
-"brochure.\n"
+"brochure."
 };
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "HexagonsP.h"
+#define TITLE "whexagons"
+
+static HexagonsRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->hexagons.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#include <Xm/ToggleB.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Hexagons.h"
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "hexagons.t.xpm"
+#include "hexagons.p.xpm"
+#include "hexagons.s.xpm"
+#include "hexagons.m.xpm"
+#include "hexagons.l.xpm"
+#include "hexagons.xpm"
+#else
+#include "pixmaps/hexagons.t.xpm"
+#include "pixmaps/hexagons.p.xpm"
+#include "pixmaps/hexagons.s.xpm"
+#include "pixmaps/hexagons.m.xpm"
+#include "pixmaps/hexagons.l.xpm"
+#include "pixmaps/hexagons.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?hexagons_t_xpm:hexagons_p_xpm):\
+(((s)<=24)?hexagons_s_xpm:hexagons_m_xpm)):\
+(((s)<=48)?hexagons_l_xpm:hexagons_xpm)))
+#endif
+#include "pixmaps/hexagons.xbm"
+#define DEFINE_XBM (char *) hexagons_bits, hexagons_width, hexagons_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "hexagons.scores"
 #endif
@@ -495,7 +504,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -1055,6 +1064,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1219,7 +1229,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1245,7 +1255,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1385,7 +1395,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
