@@ -20,78 +20,13 @@
 
 /* Driver file for Mball */
 
-#include "file.h"
-#ifdef WINVER
-#include "MballP.h"
-#define TITLE "wmball"
-
-static MballRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->mball.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#include <Xm/ToggleB.h>
-#include <Xm/ToggleBG.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Mball.h"
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/mball.t.xpm"
-#include "pixmaps/mball.p.xpm"
-#include "pixmaps/mball.s.xpm"
-#include "pixmaps/mball.m.xpm"
-#include "pixmaps/mball.l.xpm"
-#include "pixmaps/mball.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?mball_t_xpm:mball_p_xpm):\
-(((s)<=24)?mball_s_xpm:mball_m_xpm)):\
-(((s)<=48)?mball_l_xpm:mball_xpm))
-#endif
-#include "pixmaps/mball.xbm"
-#define DEFINE_XBM (char *) mball_bits, mball_width, mball_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Mball Version 7.4\n"
+"Mball Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -103,7 +38,7 @@ static const char optionsHelp[] = {
 "[-moveSound {filename}] [-{font|fn} {fontname}]\n"
 "[-wedges {int}] [-ring {int}] [-[no]orient]\n"
 "[-[no]practice] [-base {int}] [-userName {string}]\n"
-"[-scoreFile {filename}] [-scores] [-version]\n"
+"[-scoreFile {filename}] [-scores] [-version]"
 };
 #endif
 
@@ -124,7 +59,7 @@ static const char descriptionHelp[] = {
 "be arranged in 355,682,548,566,633,480,192,000,000 different "
 "possible combinations.  Masterball was invented by Dr.\n"
 "Geza Gyovai Hungarian Engineer, manufactured by Whole "
-"Systems Design, Inc..\n"
+"Systems Design, Inc.."
 };
 
 static const char featuresHelp[] = {
@@ -195,18 +130,92 @@ static const char featuresHelp[] = {
 "\n"
 "Use the control key and the left mouse button, keypad, or "
 "arrow keys to move the whole Masterball.  This is not\n"
-"recorded as a turn.\n"
+"recorded as a turn."
 };
 
 static const char referencesHelp[] = {
-"http://wsd.com/masterball\n"
+"http://wsd.com/masterball"
 };
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "MballP.h"
+#define TITLE "wmball"
+
+static MballRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->mball.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#include <Xm/ToggleB.h>
+#include <Xm/ToggleBG.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Mball.h"
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "mball.t.xpm"
+#include "mball.p.xpm"
+#include "mball.s.xpm"
+#include "mball.m.xpm"
+#include "mball.l.xpm"
+#include "mball.xpm"
+#else
+#include "pixmaps/mball.t.xpm"
+#include "pixmaps/mball.p.xpm"
+#include "pixmaps/mball.s.xpm"
+#include "pixmaps/mball.m.xpm"
+#include "pixmaps/mball.l.xpm"
+#include "pixmaps/mball.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?mball_t_xpm:mball_p_xpm):\
+(((s)<=24)?mball_s_xpm:mball_m_xpm)):\
+(((s)<=48)?mball_l_xpm:mball_xpm)))
+#endif
+#include "pixmaps/mball.xbm"
+#define DEFINE_XBM (char *) mball_bits, mball_width, mball_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "mball.scores"
 #endif
@@ -524,7 +533,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -1152,6 +1161,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1343,7 +1353,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1369,7 +1379,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1520,7 +1530,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
