@@ -20,83 +20,13 @@
 
 /* Driver file for Mlink */
 
-/*-
-  Version 7: 03/11/15 X/Windows
-  Version 5: 95/10/01 Xt/Motif
-  Version 4: 94/08/30 Xt
-*/
-
-#include "file.h"
-#ifdef WINVER
-#include "MlinkP.h"
-#define TITLE "wmlink"
-
-static MlinkRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->mlink.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#include <Xm/ToggleB.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Mlink.h"
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/mlink.t.xpm"
-#include "pixmaps/mlink.p.xpm"
-#include "pixmaps/mlink.s.xpm"
-#include "pixmaps/mlink.m.xpm"
-#include "pixmaps/mlink.l.xpm"
-#include "pixmaps/mlink.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?mlink_t_xpm:mlink_p_xpm):\
-(((s)<=24)?mlink_s_xpm:mlink_m_xpm)):\
-(((s)<=48)?mlink_l_xpm:mlink_xpm))
-#endif
-#include "pixmaps/mlink.xbm"
-#define DEFINE_XBM (char *) mlink_bits, mlink_width, mlink_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Mlink Version 7.4\n"
+"Mlink Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -110,7 +40,7 @@ static const char optionsHelp[] = {
 "[-{font|fn} {fontname}] [-tiles {int}] [-faces {int}]\n"
 "[-[no]orient] [-[no]middle] [-base {int}]\n"
 "[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-"[-version]\n"
+"[-version]"
 };
 #endif
 
@@ -120,7 +50,7 @@ static const char descriptionHelp[] = {
 "of Rubik's Cube craze.  There are  many variations on this\n"
 "theme, including the \"6x6\" puzzle and Babylon Tower.  What "
 "makes the Missing Link a harder puzzle to solve is that the\n"
-"2 center positions rotate together.\n"
+"2 center positions rotate together."
 };
 
 static const char featuresHelp[] = {
@@ -180,7 +110,7 @@ static const char featuresHelp[] = {
 "all the tiles.\n"
 "\n"
 "Use the control key and the keypad or arrow keys to reduce "
-"or enlarge the complexity of the puzzle.\n"
+"or enlarge the complexity of the puzzle."
 };
 
 static const char referencesHelp[] = {
@@ -188,15 +118,88 @@ static const char referencesHelp[] = {
 "Mathematics Series), Oxford University\n"
 "Press 1986, Plate X.\n"
 "you are about to find the solution: The Missing Link, "
-"Ideal Toy Corporation, 1981.\n"
+"Ideal Toy Corporation, 1981."
 };
 #endif
 
 static const char solveHelp[] = {
 "Auto-solver: sorry, only implemented "
-"for tiles = 4 and faces = 4.\n"
+"for tiles = 4 and faces = 4."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "MlinkP.h"
+#define TITLE "wmlink"
+
+static MlinkRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->mlink.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#include <Xm/ToggleB.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Mlink.h"
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "mlink.t.xpm"
+#include "mlink.p.xpm"
+#include "mlink.s.xpm"
+#include "mlink.m.xpm"
+#include "mlink.l.xpm"
+#include "mlink.xpm"
+#else
+#include "pixmaps/mlink.t.xpm"
+#include "pixmaps/mlink.p.xpm"
+#include "pixmaps/mlink.s.xpm"
+#include "pixmaps/mlink.m.xpm"
+#include "pixmaps/mlink.l.xpm"
+#include "pixmaps/mlink.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?mlink_t_xpm:mlink_p_xpm):\
+(((s)<=24)?mlink_s_xpm:mlink_m_xpm)):\
+(((s)<=48)?mlink_l_xpm:mlink_xpm)))
+#endif
+#include "pixmaps/mlink.xbm"
+#define DEFINE_XBM (char *) mlink_bits, mlink_width, mlink_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "mlink.scores"
 #endif
@@ -522,7 +525,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -1195,6 +1198,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1436,7 +1440,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1462,7 +1466,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1609,7 +1613,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
