@@ -2416,7 +2416,7 @@ randomizePieces(OctWidget w)
 static void
 solvePieces(OctWidget w)
 {
-	if (checkSolved(w) && w->oct.currentFace > IGNORE_DIR)
+	if (checkSolved(w) || w->oct.currentFace > IGNORE_DIR)
 		return;
 	{
 		setPuzzle(w, ACTION_SOLVE_MESSAGE);
