@@ -20,78 +20,13 @@
 
 /* Driver file for Oct */
 
-#include "file.h"
-#ifdef WINVER
-#include "OctP.h"
-#define TITLE "woct"
-
-static OctRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->oct.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#include <Xm/ToggleB.h>
-#include <Xm/ToggleBG.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Oct.h"
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/oct.t.xpm"
-#include "pixmaps/oct.p.xpm"
-#include "pixmaps/oct.s.xpm"
-#include "pixmaps/oct.m.xpm"
-#include "pixmaps/oct.l.xpm"
-#include "pixmaps/oct.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?oct_t_xpm:oct_p_xpm):\
-(((s)<=24)?oct_s_xpm:oct_m_xpm)):\
-(((s)<=48)?oct_l_xpm:oct_xpm))
-#endif
-#include "pixmaps/oct.xbm"
-#define DEFINE_XBM (char *) oct_bits, oct_width, oct_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Oct Version 7.4\n"
+"Oct Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -103,7 +38,7 @@ static const char optionsHelp[] = {
 "[-{font|fn} {fontname}] [-{size {int} | sticky}]\n"
 "[-{mode {int} | both}] [-[no]orient] [-[no]practice]\n"
 "[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-"[-version]\n"
+"[-version]"
 };
 #endif
 
@@ -127,7 +62,7 @@ static const char descriptionHelp[] = {
 "One is able to simulate a Trajber's Octahedron (period "
 "3 turning and sticky mode).  Also one is able to\n"
 "simulate one with variant turning (period 4 turning and "
-"sticky mode).\n"
+"sticky mode)."
 };
 
 static const char featuresHelp[] = {
@@ -212,21 +147,95 @@ static const char featuresHelp[] = {
 "Points turn in \"Period 4\" and faces turn in \"Period 3\".\n"
 "Use the control key and the left mouse button, keypad, or "
 "arrow keys to move the whole octahedron.  This is not\n"
-"recorded as a turn.\n"
+"recorded as a turn."
 };
 
 static const char referencesHelp[] = {
 "Beyond Rubik's Cube: spheres, pyramids, dodecahedrons and "
 "God knows what else by Douglas R. Hofstadter,\n"
 "Scientific American, July 1982, pp 16-31.\n"
-"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
+"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow."
 };
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "OctP.h"
+#define TITLE "woct"
+
+static OctRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->oct.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#include <Xm/ToggleB.h>
+#include <Xm/ToggleBG.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Oct.h"
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "oct.t.xpm"
+#include "oct.p.xpm"
+#include "oct.s.xpm"
+#include "oct.m.xpm"
+#include "oct.l.xpm"
+#include "oct.xpm"
+#else
+#include "pixmaps/oct.t.xpm"
+#include "pixmaps/oct.p.xpm"
+#include "pixmaps/oct.s.xpm"
+#include "pixmaps/oct.m.xpm"
+#include "pixmaps/oct.l.xpm"
+#include "pixmaps/oct.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?oct_t_xpm:oct_p_xpm):\
+(((s)<=24)?oct_s_xpm:oct_m_xpm)):\
+(((s)<=48)?oct_l_xpm:oct_xpm)))
+#endif
+#include "pixmaps/oct.xbm"
+#define DEFINE_XBM (char *) oct_bits, oct_width, oct_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "oct.scores"
 #endif
@@ -559,7 +568,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -1241,6 +1250,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1459,7 +1469,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1485,7 +1495,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1639,7 +1649,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
