@@ -177,6 +177,9 @@ static XtResource resources[] =
 	{XtNmoveSound, XtCMoveSound, XtRString, sizeof (String),
 	 XtOffset(PanexWidget, panex.moveSound),
 	 XtRString, (caddr_t) MOVESOUND},
+	{XtNdripSound, XtCDripSound, XtRString, sizeof (String),
+	 XtOffset(PanexWidget, panex.dripSound),
+	 XtRString, (caddr_t) DRIPSOUND},
 	{XtNfont, XtCFont, XtRString, sizeof (String),
 	 XtOffset(PanexWidget, panex.font),
 	 XtRString, (caddr_t) "9x15bold"},
@@ -185,7 +188,7 @@ static XtResource resources[] =
 	 XtRString, (caddr_t) "10"}, /* DEFAULT_TILES */
 	{XtNmode, XtCMode, XtRInt, sizeof (int),
 	 XtOffset(PanexWidget, panex.mode),
-	 XtRString, (caddr_t) "1"}, /* DEFAULT_MODE */
+	 XtRString, (caddr_t) "2"}, /* DEFAULT_MODE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(PanexWidget, panex.userName),
 	 XtRString, (caddr_t) ""},
@@ -313,11 +316,13 @@ loadFont(PanexWidget w)
 static int startPositions[MAX_MODES][MAX_STACKS] =
 {
 	{0, -1, -1},
+	{0, -1, 1},
 	{0, -1, 1}
 };
 static int finishPositions[MAX_MODES][MAX_STACKS] =
 {
 	{-1, -1, 0},
+	{1, -1, 0},
 	{1, -1, 0}
 };
 
@@ -352,9 +357,19 @@ checkTiles(PanexWidget w)
 		w->panex.tiles = DEFAULT_TILES;
 	}
 	if (w->panex.mode < HANOI || w->panex.mode > PANEX) {
-		intCat(&buf1,
-			"Mode is in error, use 0 for Hanoi, 1 for Panex, defaulting to ",
-			DEFAULT_MODE);
+		intCat(&buf1, "Mode is in error, use ", HANOI);
+		stringCat(&buf2, buf1, " for Hanoi, ");
+		free(buf1);
+		intCat(&buf1, buf2, ALGORITHME);
+		free(buf2);
+		stringCat(&buf2, buf1, " for Algorithme, ");
+		free(buf1);
+		intCat(&buf1, buf2, PANEX);
+		free(buf2);
+		stringCat(&buf2, buf1, " for Panex, defaulting to ");
+		free(buf1);
+		intCat(&buf1, buf2, DEFAULT_MODE);
+		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
 		w->panex.mode = DEFAULT_MODE;
@@ -395,10 +410,10 @@ checkMiddle(PanexWidget w)
 
 	for (stack = 0; stack < MAX_STACKS; stack++)
 		if ((i.stack = middlePositions[stack]) >= 0)
-			for (loc = 1; loc <= w->panex.tiles; loc++) {
+			for (loc = 0; loc < w->panex.tiles; loc++) {
 				i.loc = loc - 1;
-				if (w->panex.tileOfPosition[stack][loc].stack != i.stack ||
-						w->panex.tileOfPosition[stack][loc].loc != i.loc)
+				if (w->panex.tileOfPosition[stack][loc + w->panex.blanks].stack != i.stack ||
+						w->panex.tileOfPosition[stack][loc + w->panex.blanks].loc != i.loc)
 					return False;
 			}
 	return True;
@@ -413,10 +428,10 @@ checkSolved(PanexWidget w)
 
 	for (stack = 0; stack < MAX_STACKS; stack++)
 		if ((i.stack = finishPositions[w->panex.mode][stack]) >= 0)
-			for (loc = 1; loc <= w->panex.tiles; loc++) {
-				i.loc = loc - 1;
-				if (w->panex.tileOfPosition[stack][loc].stack != i.stack ||
-						w->panex.tileOfPosition[stack][loc].loc != i.loc)
+			for (loc = 0; loc < w->panex.tiles; loc++) {
+				i.loc = loc;
+				if (w->panex.tileOfPosition[stack][loc + w->panex.blanks].stack != i.stack ||
+						w->panex.tileOfPosition[stack][loc + w->panex.blanks].loc != i.loc)
 					return False;
 			}
 	return True;
@@ -429,11 +444,11 @@ printStacks(PanexWidget w)
 	int stack, position;
 
 	(void) printf("top: where are the tiles in the stack\n");
-	for (position = 0; position <= w->panex.tiles; position++)
+	for (position = 0; position < w->panex.tiles + w->panex.blanks; position++)
 		for (stack = 0; stack < MAX_STACKS; stack++) {
 			printf("%d,%d", w->panex.tileOfPosition[stack][position].stack,
 				w->panex.tileOfPosition[stack][position].loc);
-			if (stack + 1 == MAX_STACKS)
+			if (stack == MAX_STACKS - 1)
 				(void) printf("\n");
 			else
 				(void) printf(" | ");
@@ -447,10 +462,10 @@ printTiles(PanexWidget w)
 
 	(void) printf("pot: which stack are the tiles in\n");
 	for (position = 0; position < w->panex.tiles; position++)
-		for (stack = 0; stack <= w->panex.mode; stack++) {
+		for (stack = 0; stack < w->panex.stacks; stack++) {
 			printf("%d,%d", w->panex.positionOfTile[stack][position].stack,
 				w->panex.positionOfTile[stack][position].loc);
-			if (stack == w->panex.mode)
+			if (stack == w->panex.stacks - 1)
 				(void) printf("\n");
 			else
 				(void) printf(" | ");
@@ -529,8 +544,8 @@ drawPyramid(PanexWidget w, Pixmap dr, int color, int i, int j, int size,
 	trapazoidList[0].y = j * w->panex.pos.y + w->panex.delta.y +
 		w->panex.puzzleOffset.y + offsetPosition + 2;
 	if (w->panex.mono) {
-		pyramidGC = (offsetPosition) ? w->panex.tileGC[1] :
-			w->panex.inverseGC[4];
+		pyramidGC = (offsetPosition) ? w->panex.tileGC[4] :
+			w->panex.inverseGC[1];
 	} else {
 #ifndef WINVER
 		if ((w->panex.pyramidColor[color] == w->panex.borderColor)
@@ -607,22 +622,24 @@ drawSlot(PanexWidget w, int stack, int x, int y, int width, int height)
 		sizex + (MAX_STACKS - 1) * w->panex.pos.x,
 		sizey,
 		x, y, width, height);
-	fillRectClip(w, dr, w->panex.inverseGC[4],
-		sizex + w->panex.delta.x +
-		w->panex.puzzleOffset.x + stack * w->panex.pos.x,
-		w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey,
-		sizex,
-		(w->panex.tiles + 1) * w->panex.pos.y + w->panex.delta.y -
-		1 - 2 * sizey,
-		x, y, width, height);
-	fillRectClip(w, dr, w->panex.inverseGC[4],
-		sizex + w->panex.delta.x +
-		w->panex.puzzleOffset.x + w->panex.pos.x,
-		w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey,
-		sizex,
-		(w->panex.tiles + 1) * w->panex.pos.y + w->panex.delta.y -
-		1 - 2 * sizey,
-		x, y, width, height);
+	if ((w->panex.mode != ALGORITHME) || w->panex.tiles != 1) {
+		fillRectClip(w, dr, w->panex.inverseGC[4],
+			sizex + w->panex.delta.x +
+			w->panex.puzzleOffset.x + stack * w->panex.pos.x,
+			w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey,
+			sizex,
+			(w->panex.tiles + w->panex.blanks) * w->panex.pos.y + w->panex.delta.y -
+			1 - 2 * sizey,
+			x, y, width, height);
+		fillRectClip(w, dr, w->panex.inverseGC[4],
+			sizex + w->panex.delta.x +
+			w->panex.puzzleOffset.x + w->panex.pos.x,
+			w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey,
+			sizex,
+			(w->panex.tiles + w->panex.blanks) * w->panex.pos.y + w->panex.delta.y -
+			1 - 2 * sizey,
+			x, y, width, height);
+	}
 }
 
 static void
@@ -634,6 +651,9 @@ drawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 	int tileJ = w->panex.tileOfPosition[i][j].loc;
 	Pixmap dr = 0;
 
+	if (i < 0 || j < 0) {
+		(void) printf("drawTile: i = %d, j = %d\n", i, j);
+	}
 	dx = cartesianX(w, i) + pressedOffset + offsetX;
 	dy = cartesianY(w, j) + pressedOffset + offsetY;
 	sx = cartesianX(w, tileI);
@@ -668,13 +688,15 @@ drawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 					w->panex.tileSize.x + 1,
 					w->panex.tileSize.y / 3);
 			}
-			FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
-				dx + w->panex.tileSize.x / 3 - pressedOffset,
-				dy + w->panex.tileSize.y / 3 - 1,
-				w->panex.tileSize.x / 3,
-				w->panex.tileSize.y - w->panex.tileSize.y / 3 +
-				2 - pressedOffset);
-		} else if (j == w->panex.tiles) {
+			if ((w->panex.mode != ALGORITHME) || w->panex.tiles != 1) {
+				FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
+					dx + w->panex.tileSize.x / 3 - pressedOffset,
+					dy + w->panex.tileSize.y / 3 - 1,
+					w->panex.tileSize.x / 3,
+					w->panex.tileSize.y - w->panex.tileSize.y / 3 +
+					2 - pressedOffset);
+			}
+		} else if (j == w->panex.tiles + w->panex.blanks - 1) {
 			FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
 				dx + w->panex.tileSize.x / 3 - pressedOffset,
 				dy - pressedOffset,
@@ -742,23 +764,12 @@ drawBufferedTile(PanexWidget w, int i, int j, int pressedOffset)
 		i, i, j, j, pressedOffset);
 }
 
-static void
-drawAllBufferedTiles(const PanexWidget w)
-{
-	int i, j, l;
-
-	for (i = 0; i <= w->panex.mode; i++)
-		for (j = 0; j < w->panex.tiles; j++)
-			for (l = 0; l < 2; l++)
-				drawBufferedTile(w, i, j, l);
-}
-
 void
 drawAllTiles(PanexWidget w)
 {
 	int i, j;
 
-	for (i = 0; i <= w->panex.mode; i++)
+	for (i = 0; i < w->panex.stacks; i++)
 		for (j = 0; j < w->panex.tiles; j++)
 			drawTile(w,
 				w->panex.positionOfTile[i][j].stack,
@@ -766,6 +777,17 @@ drawAllTiles(PanexWidget w)
 				False, FALSE, 0, 0);
 }
 
+static void
+drawAllBufferedTiles(const PanexWidget w)
+{
+	int i, j, l;
+
+	for (i = 0; i < w->panex.stacks; i++)
+		for (j = 0; j < w->panex.tiles; j++)
+			for (l = 0; l < 2; l++)
+				drawBufferedTile(w, i, j, l);
+}
+
 static void
 animateSlide(PanexWidget w, int currentStack, int currentPosition,
 		int nextStack, int nextPosition, int fast)
@@ -871,16 +893,18 @@ drawSlots(PanexWidget w, Pixmap dr)
 	if (sizey == 0)
 		sizey = 1;
 	dx = sizex + w->panex.delta.x + w->panex.puzzleOffset.x;
-	y = (w->panex.tiles + 1) * w->panex.pos.y + w->panex.delta.y;
+	y = (w->panex.tiles + w->panex.blanks) * w->panex.pos.y +
+		w->panex.delta.y;
 	dy = w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey;
 	FILLRECTANGLE(w, dr, w->panex.inverseGC[4], dx, dy,
 		sizex + (MAX_STACKS - 1) * w->panex.pos.x,
 		sizey);
-	for (i = 0; i < MAX_STACKS; i++) {
-		FILLRECTANGLE(w, dr, w->panex.inverseGC[4], dx, dy,
-			sizex, y - 1 - 2 * sizey);
-		dx += w->panex.pos.x;
-	}
+	if ((w->panex.mode != ALGORITHME) || w->panex.tiles != 1)
+		for (i = 0; i < MAX_STACKS; i++) {
+			FILLRECTANGLE(w, dr, w->panex.inverseGC[4], dx, dy,
+				sizex, y - 1 - 2 * sizey);
+			dx += w->panex.pos.x;
+		}
 }
 
 static void
@@ -942,12 +966,21 @@ topOfStack(PanexWidget w, int stack, int start)
 {
 	int i;
 
-	for (i = start; i <= w->panex.tiles; i++)
+	for (i = start; i < w->panex.tiles + w->panex.blanks; i++)
 		if (w->panex.tileOfPosition[stack][i].stack >= 0)
 			return i;
 	return -1;
 }
 
+static Boolean
+jumpMove(PanexWidget w, int fromStack, int toStack)
+{
+	return (((w->panex.mode == ALGORITHME) &&
+		(w->panex.tileOfPosition[1][0].stack >= 0) &&
+		((toStack == 0 && fromStack == 2) ||
+		(toStack == 2 && fromStack == 0))));
+}
+
 static int
 requestMove(PanexWidget w, int fromStack, int fromPosition, int toStack,
 		Boolean limbo)
@@ -956,34 +989,45 @@ requestMove(PanexWidget w, int fromStack, int fromPosition, int toStack,
 
 	/* Do not have to check above stack since it is the top one */
 	if (toStack > fromStack) {
-		for (i = fromStack + 1; i <= toStack; i++) {
-			if (w->panex.tileOfPosition[i][0].stack >= 0)
-				return (-1);
+		if (!jumpMove(w, fromStack, toStack)) {
+			for (i = fromStack + 1; i <= toStack; i++) {
+				if (w->panex.tileOfPosition[i][0].stack >= 0)
+					return (-1);
+			}
 		}
 		i = topOfStack(w, toStack, 0);
 	} else if (toStack < fromStack) {
-		for (i = fromStack - 1; i >= toStack; i--) {
-			if (w->panex.tileOfPosition[i][0].stack >= 0)
-				return (-1);
+		if (!jumpMove(w, fromStack, toStack)) {
+			for (i = fromStack - 1; i >= toStack; i--) {
+				if (w->panex.tileOfPosition[i][0].stack >= 0)
+					return (-1);
+			}
 		}
 		i = topOfStack(w, toStack, 0);
 	} else {
 		/* Ruled out toStack == fromStack, except for motion */
 		i = topOfStack(w, toStack, 1);
 	}
-	i = (i == -1) ? w->panex.tiles : i - 1;
+	i = (i == -1) ? w->panex.tiles + w->panex.blanks - 1 : i - 1;
 	if (w->panex.mode == HANOI) {
-		if (i == w->panex.tiles || limbo ||
+		if (i == w->panex.tiles + w->panex.blanks - 1 || limbo ||
 				w->panex.tileOfPosition[toStack][i + 1].loc >=
 				w->panex.tileOfPosition[fromStack][fromPosition].loc)
 			return i;
 		else
 			return -2;
-	} else {
+	} else if (w->panex.mode == PANEX) {
 		if (i > w->panex.tileOfPosition[fromStack][fromPosition].loc + 1)
 			return (w->panex.tileOfPosition[fromStack][fromPosition].loc + 1);
 		else
 			return i;
+	} else {
+		if (i == w->panex.tiles + w->panex.blanks - 1 || limbo ||
+				w->panex.tileOfPosition[toStack][i + 1].loc >=
+				w->panex.tileOfPosition[fromStack][fromPosition].loc)
+			return i;
+		else
+			return -2;
 	}
 }
 
@@ -1035,7 +1079,7 @@ discreteMoves(PanexWidget w, int currentStack, int currentPosition,
 
 static void
 slideTile(PanexWidget w, int fromStack, int fromPosition,
-		int toStack, int toPosition, int fast)
+		int toStack, int toPosition, Boolean jump, int fast)
 {
 	int currentStack = fromStack, currentPosition = fromPosition;
 	int nextStack = fromStack, nextPosition = fromPosition;
@@ -1063,7 +1107,7 @@ slideTile(PanexWidget w, int fromStack, int fromPosition,
 #endif
 	}
 	if (currentStack != toStack) {
-		if (fast != INSTANT && w->panex.delay > 0) {
+		if (fast != INSTANT && w->panex.delay > 0 && !jump) {
 			nextStack = toStack;
 			animateSlide(w, currentStack, currentPosition,
 				nextStack, nextPosition, fast);
@@ -1072,8 +1116,11 @@ slideTile(PanexWidget w, int fromStack, int fromPosition,
 			currentStack = nextStack;
 		} else {
 			while (currentStack != toStack) {
-				nextStack = (currentStack < toStack) ?
-					currentStack + 1 : currentStack - 1;
+				if (jump)
+					nextStack = toStack;
+				else
+					nextStack = (currentStack < toStack) ?
+						currentStack + 1 : currentStack - 1;
 				nextPosition = currentPosition;
 				discreteMoves(w, currentStack, currentPosition,
 					nextStack, nextPosition);
@@ -1082,7 +1129,10 @@ slideTile(PanexWidget w, int fromStack, int fromPosition,
 		}
 #ifdef USE_SOUND
 		if (w->panex.sound) {
-			playSound((char *) MOVESOUND);
+			if (jump)
+				playSound((char *) DRIPSOUND);
+			else
+				playSound((char *) MOVESOUND);
 		}
 #endif
 	}
@@ -1118,7 +1168,7 @@ moveTile(PanexWidget w, int fromStack, int fromPosition, int toStack, int fast)
 	if ((toPosition = requestMove(w, fromStack, fromPosition, toStack,
 			False)) >= 0)
 		slideTile(w, fromStack, fromPosition, toStack, toPosition,
-			fast);
+			jumpMove(w, fromStack, toStack), fast);
 	return toPosition;
 }
 
@@ -1130,7 +1180,8 @@ moveTileToLimbo(PanexWidget w, int fromStack, int fromPosition, int toStack,
 
 	aMove = (requestMove(w, fromStack, fromPosition, toStack, limbo) >= 0);
 	if (aMove)
-		slideTile(w, fromStack, fromPosition, toStack, 0, NORMAL);
+		slideTile(w, fromStack, fromPosition, toStack, 0,
+			jumpMove(w, fromStack, toStack), NORMAL);
 	return aMove;
 }
 
@@ -1140,8 +1191,16 @@ resetTiles(PanexWidget w)
 	int stack, loc;
 	PanexLoc i;
 
+	w->panex.stacks = ((w->panex.mode == HANOI) ? 1 : 2);
+	if (w->panex.mode == ALGORITHME) {
+		if (w->panex.tiles == 1)
+			w->panex.blanks = 0;
+		else if (w->panex.tiles > 1)
+			w->panex.blanks = w->panex.tiles - 2;
+	} else
+		w->panex.blanks = 1;
 	w->panex.currentStack = -1;
-	for (stack = 0; stack < MAX_MODES; stack++) {
+	for (stack = 0; stack < w->panex.stacks; stack++) {
 		if (w->panex.positionOfTile[stack]) {
 			free(w->panex.positionOfTile[stack]);
 			w->panex.positionOfTile[stack] = NULL;
@@ -1151,7 +1210,7 @@ resetTiles(PanexWidget w)
 			startLoc[stack] = NULL;
 		}
 	}
-	for (stack = 0; stack <= w->panex.mode; stack++) {
+	for (stack = 0; stack < w->panex.stacks; stack++) {
 		if (!(w->panex.positionOfTile[stack] = (PanexLoc *)
 				malloc(sizeof (PanexLoc) * w->panex.tiles))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1166,28 +1225,33 @@ resetTiles(PanexWidget w)
 			free(w->panex.tileOfPosition[stack]);
 		if (!(w->panex.tileOfPosition[stack] = (PanexLoc *)
 				malloc(sizeof (PanexLoc) *
-				(w->panex.tiles + 1)))) {
+				(w->panex.tiles + w->panex.blanks)))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
-	for (stack = 0; stack <= w->panex.mode; stack++) {
+	for (stack = 0; stack < w->panex.stacks; stack++) {
 		i.stack = 2 * stack;
 		for (loc = 0; loc < w->panex.tiles; loc++) {
-			i.loc = loc + 1;
+			i.loc = loc + w->panex.blanks;
 			w->panex.positionOfTile[stack][loc] = i;
 		}
 	}
 	for (stack = 0; stack < MAX_STACKS; stack++) {
 		i.stack = -1;
 		i.loc = -1;
-		w->panex.tileOfPosition[stack][0] = i;
-		if ((i.stack = startPositions[w->panex.mode][stack]) >= 0)
-			for (loc = 1; loc <= w->panex.tiles; loc++) {
-				i.loc = loc - 1;
-				w->panex.tileOfPosition[stack][loc] = i;
-		} else
-			for (loc = 1; loc <= w->panex.tiles; loc++)
-				w->panex.tileOfPosition[stack][loc] = i;
+		for (loc = 0; loc < w->panex.blanks; loc++) {
+			w->panex.tileOfPosition[stack][loc] = i;
+		}
+		if ((i.stack = startPositions[w->panex.mode][stack]) >= 0) {
+			for (loc = 0; loc < w->panex.tiles; loc++) {
+				i.loc = loc;
+				w->panex.tileOfPosition[stack][loc + w->panex.blanks] = i;
+			}
+		} else {
+			for (loc = 0; loc < w->panex.tiles; loc++) {
+				w->panex.tileOfPosition[stack][loc + w->panex.blanks] = i;
+			}
+		}
 	}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
@@ -1293,9 +1357,12 @@ getTiles(PanexWidget w)
 	setStartPosition(w);
 	scanMoves(fp, w, moves);
 	(void) fclose(fp);
-	if (mode == 0)
+	if (mode == HANOI)
 		(void) printf("%s: mode hanoi, tiles %d, moves %d.\n",
 			name, tiles, moves);
+	else if (mode == ALGORITHME)
+		(void) printf("%s: mode algorithme, tiles %d, moves %d.\n",
+			name, tiles, moves);
 	else
 		(void) printf("%s: mode panex, tiles %d, moves %d.\n",
 			name, tiles, moves);
@@ -1536,6 +1603,7 @@ setValuesPuzzle(PanexWidget w)
 		DEFAULT_TILES, INIFILE);
 	w->panex.mode = GetPrivateProfileInt(SECTION, "mode",
 		DEFAULT_MODE, INIFILE);
+	w->panex.stacks = ((w->panex.mode == HANOI) ? 1 : 2);
 	w->panex.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
 		DEFAULT_MONO, INIFILE);
 	w->panex.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
@@ -1565,7 +1633,7 @@ setValuesPuzzle(PanexWidget w)
 	w->panex.inverseGC[4] = RGB(darker(darker(darker(color.red))),
 		darker(darker(darker(color.green))),
 		darker(darker(darker(color.blue))));
-	for (pyramid = 0; pyramid < MAX_STACKS - 1; pyramid++) {
+	for (pyramid = 0; pyramid < w->panex.stacks; pyramid++) {
 		(void) sprintf(buf, "pyramidColor%d", pyramid);
 		(void) GetPrivateProfileString(SECTION,
 			buf, pyramidColorString[pyramid],
@@ -1587,35 +1655,7 @@ setValuesPuzzle(PanexWidget w)
 		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
 	(void) GetPrivateProfileString(SECTION, "moveSound", MOVESOUND,
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->panex.moveSound, szBuf);
-		w->panex.moveSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->panex.userName, szBuf);
-	w->panex.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	for (pyramid = 0; pyramid < MAX_STACKS - 1; pyramid++) {
-		(void) sprintf(buf, "pyramidColor%d", pyramid);
-		(void) GetPrivateProfileString(SECTION,
-			buf, pyramidColorString[pyramid],
-			szBuf, sizeof (szBuf), INIFILE);
-		(void) sscanf(szBuf, "%d %d %d",
-			&(color.red), &(color.green), &(color.blue));
-		w->panex.pyramidGC[pyramid] =
-			RGB(color.red, color.green, color.blue);
-		(void) sprintf(buf, "pyramidChar%d", pyramid);
-		charbuf[0] = pyramidColorChar[pyramid];
-		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
-		w->panex.pyramidChar[pyramid] = szBuf[0];
-	}
-	w->panex.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULT_DELAY, INIFILE);
-	w->panex.sound = (BOOL)
-		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
-	(void) GetPrivateProfileString(SECTION, "moveSound", MOVESOUND,
+	(void) GetPrivateProfileString(SECTION, "dripSound", DRIPSOUND,
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->panex.moveSound, szBuf);
 		w->panex.moveSound[80] = 0;
@@ -1743,8 +1783,8 @@ setAllColors(PanexWidget w)
 		values.foreground = w->panex.foreground;
 		values.background = w->panex.background;
 	} else {
-		values.foreground = w->panex.background;
 		values.background = w->panex.foreground;
+		values.foreground = w->panex.background;
 	}
 	if (w->panex.inverseGC[1])
 		XtReleaseGC((Widget) w, w->panex.inverseGC[1]);
@@ -1770,10 +1810,18 @@ setAllColors(PanexWidget w)
 	if (w->panex.inverseGC[3])
 		XtReleaseGC((Widget) w, w->panex.inverseGC[3]);
 	w->panex.inverseGC[3] = XtGetGC((Widget) w, valueMask, &values);
-	if (!w->panex.mono) {
+	if (w->panex.mono) {
+		if (w->panex.reverse) {
+			values.background = w->panex.foreground;
+			values.foreground = w->panex.background;
+		} else {
+			values.foreground = w->panex.foreground;
+			values.background = w->panex.background;
+		}
+	} else {
 		values.foreground = darker(w, darker(w, darker(w,
 			(w->panex.reverse) ?
-			w->panex.foreground : w->panex.background)));
+			w->panex.background : w->panex.foreground)));
 	}
 	if (w->panex.inverseGC[4])
 		XtReleaseGC((Widget) w, w->panex.inverseGC[4]);
@@ -1810,7 +1858,7 @@ setAllColors(PanexWidget w)
 	if (w->panex.tileGC[2])
 		XtReleaseGC((Widget) w, w->panex.tileGC[2]);
 	w->panex.tileGC[2] = XtGetGC((Widget) w, valueMask, &values);
-	for (pyramid = 0; pyramid <= w->panex.mode; pyramid++)
+	for (pyramid = 0; pyramid < w->panex.stacks; pyramid++)
 		getColor(w, pyramid);
 	if (w->panex.fontInfo)
 		XSetFont(XtDisplay(w), w->panex.inverseGC[4],
@@ -1826,11 +1874,13 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 	int pyramid;
 
 	checkTiles(w);
-	for (pyramid = 0; pyramid <= w->panex.mode; pyramid++) {
-		if (strcmp(w->panex.pyramidName[pyramid],
-				c->panex.pyramidName[pyramid])) {
-			setColors = True;
-			break;
+	if (w->panex.mode == c->panex.mode) {
+		for (pyramid = 0; pyramid < w->panex.stacks; pyramid++) {
+			if (strcmp(w->panex.pyramidName[pyramid],
+					c->panex.pyramidName[pyramid])) {
+				setColors = True;
+				break;
+			}
 		}
 	}
 	if (w->panex.font != c->panex.font ||
@@ -1849,12 +1899,13 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 		setAllColors(w);
 		redrawTiles = True;
 	}
-	if (w->panex.tiles != c->panex.tiles) {
+	if (w->panex.mode != c->panex.mode) {
 		eraseFrame(c, 0, False);
 		sizePuzzle(w);
 		redraw = True;
-	} else if (w->panex.mode != c->panex.mode) {
-		resetTiles(w);
+	} else if (w->panex.tiles != c->panex.tiles) {
+		eraseFrame(c, 0, False);
+		sizePuzzle(w);
 		redraw = True;
 	} else if (w->panex.puzzleOffset.x != c->panex.puzzleOffset.x ||
 			w->panex.puzzleOffset.y != c->panex.puzzleOffset.y) {
@@ -1927,7 +1978,7 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
-	for (i = 0; i <= w->panex.mode; i++)
+	for (i = 0; i < w->panex.stacks; i++)
 		XtReleaseGC(old, w->panex.pyramidGC[i]);
 	for (i = 0; i < FG_SHADES; i++)
 		XtReleaseGC(old, w->panex.tileGC[i]);
@@ -2017,9 +2068,9 @@ resizePuzzle(PanexWidget w)
 	w->panex.pos.x = MAX(((int) w->core.width - w->panex.delta.x) /
 			MAX_STACKS, w->panex.delta.x);
 	w->panex.pos.y = MAX(((int) w->core.height - 2 * w->panex.delta.y - 3) /
-			(w->panex.tiles + 1), w->panex.delta.y);
+			(w->panex.tiles + w->panex.blanks), w->panex.delta.y);
 	w->panex.width = w->panex.pos.x * MAX_STACKS + w->panex.delta.x + 2;
-	w->panex.height = w->panex.pos.y * (w->panex.tiles + 1) +
+	w->panex.height = w->panex.pos.y * (w->panex.tiles + w->panex.blanks) +
 		w->panex.delta.y + 3;
 	w->panex.puzzleOffset.x = ((int) w->core.width - w->panex.width + 2) / 2;
 	w->panex.puzzleOffset.y = ((int) w->core.height - w->panex.height + 2) / 2;
@@ -2065,7 +2116,8 @@ Widget request, Widget renew
 	int i;
 
 	(void) SRAND(getpid());
-	for (stack = 0; stack <= w->panex.mode; stack++)
+	w->panex.stacks = ((w->panex.mode == HANOI) ? 1 : 2);
+	for (stack = 0; stack < w->panex.stacks; stack++)
 		w->panex.pyramidGC[stack] = NULL;
 	w->panex.bufferTiles[0] = None;
 	w->panex.bufferTiles[1] = None;
@@ -2080,6 +2132,8 @@ Widget request, Widget renew
 	loadFont(w);
 	for (stack = 0; stack < MAX_STACKS; stack++) {
 		w->panex.tileOfPosition[stack] = NULL;
+	}
+	for (stack = 0; stack < w->panex.stacks; stack++) {
 		w->panex.positionOfTile[stack] = NULL;
 	}
 	checkTiles(w);
