@@ -151,7 +151,7 @@ moveATile(PanexWidget w, int fromStack, int toStack)
 		longjmp(solve_env, 1);
 #endif
 	if ((fromPosition = topOfStack(w, fromStack, 0)) < 0 ||
-			movePuzzle(w, fromStack, fromPosition, toStack, NORMAL) < 0) {
+			movePuzzle(w, fromStack, fromPosition, toStack, DOUBLE) < 0) {
 		(void) printf("move from %d to %d can not be made.",
 			fromStack, toStack);
 		return False;
@@ -250,6 +250,292 @@ printStacks(PanexWidget w)
 }
 #endif
 
+static void
+moveStack(PanexWidget w, int n, int a, int b) {
+	int c;
+
+	if ((a == 0 || b == 0) && (a == 1 || b == 1)) {
+		c = 2;
+	} else if ((a == 1 || b == 1) && (a == 2 || b == 2)) {
+		c = 0;
+	} else {
+		c = 1;
+	}
+	if (n > 1)
+		moveStack(w, n - 1, a, c);
+	moveATile(w, a, b);
+	moveATile(w, a, b);
+	if (n > 1)
+		moveStack(w, n - 1, c, b);
+}
+
+static void
+cStack(PanexWidget w, int n, Boolean side, Boolean inv) {
+	int first, last;
+	/*int start = counter;*/
+
+	if (side) {
+		first = 2;
+		last  = 0;
+	} else {
+		first = 0;
+		last = 2;
+	}
+	if (inv) {
+		moveStack(w, n - 2, 1, first);
+		moveATile(w, 1, last);
+		moveStack(w, n - 2, first, last);
+		moveATile(w, 1, first);
+		if (n > 3)
+			moveStack(w, n - 3, last, 1);
+		moveATile(w, last, first);
+	} else {
+		moveATile(w, first, last);
+		if (n > 3)
+			moveStack(w, n - 3, 1, last);
+		moveATile(w, first, 1);
+		moveStack(w, n - 2, last, first);
+		moveATile(w, last, 1);
+		moveStack(w, n - 2, first, 1);
+	}
+}
+
+static void
+startPart(PanexWidget w, int n, Boolean side, Boolean inv) {
+	int first, last, i;
+	/*int start = counter;*/
+
+	if (side) {
+		first = 2;
+		last  = 0;
+	} else {
+		first = 0;
+		last = 2;
+	}
+	if (inv) {
+		if (n == 2) {
+			moveATile(w, 1, last);
+			moveATile(w, 1, first);
+		} else if (n == 3) {
+			cStack(w, n, side, inv);
+		} else if (n > 3) {
+			cStack(w, n, !side, inv);
+			for (i = 1; i <= n / 2 - 2; i++)
+				cStack(w, n - 2 * i, side, inv);
+			startPart(w, (((n & 1) == 1) ? 3 : 2), side, inv);
+		}
+	} else {
+		if (n == 2) {
+			moveATile(w, first, 1);
+			moveATile(w, last, 1);
+		} else if (n == 3) {
+			cStack(w, n, side, inv);
+		} else if (n > 3) {
+			startPart(w, (((n & 1) == 1) ? 3 : 2), side, inv);
+			for (i = n / 2 - 2; i > 0; i--)
+				cStack(w, n - 2 * i, side, inv);
+			cStack(w, n, !side, inv);
+		}
+	}
+	/*if (debug)
+		(void) printf("startPart %d\n", (counter - start));*/
+}
+
+static void
+finishPart(PanexWidget w, int n, Boolean side, Boolean inv) {
+	int first, last, i;
+	/*int start = counter;*/
+
+	if (side) {
+		first = 2;
+		last  = 0;
+	} else {
+		first = 0;
+		last = 2;
+	}
+	if (inv) {
+		if (n == 3) {
+			moveStack(w, n - 2, 1, first);
+			moveATile(w, 1, last);
+			moveATile(w, first, 1);
+			moveATile(w, first, last);
+			moveATile(w, 1, last);
+			moveATile(w, 1, first);
+			moveATile(w, last, first);
+		} else if (n > 3) {
+			moveStack(w, n - 2, 1, last);
+			moveStack(w, 1, 1, first);
+			moveStack(w, n - 2, last, 1);
+			moveATile(w, first, last);
+			for (i = 0; i <= (n - 1) / 2 - 2; i++)
+				cStack(w, (n - 1) - 2 * i, !side, inv);
+			startPart(w, (((n & 1) == 1) ? 2 : 3),
+				!side, inv);
+		}
+	} else {
+		if (n == 3) {
+			moveATile(w, first, last);
+			moveATile(w, first, 1);
+			moveATile(w, last, 1);
+			moveATile(w, last, first);
+			moveATile(w, 1, first);
+			moveATile(w, last, 1);
+			moveStack(w, n - 2, first, 1);
+		} else if (n > 3) {
+			startPart(w, (((n & 1) == 1) ? 2 : 3),
+				!side, inv);
+			for (i = (n - 1) / 2 - 2; i >= 0; i--)
+				cStack(w, (n - 1) - 2 * i, !side, inv);
+			moveATile(w, last, first);
+			moveStack(w, n - 2, 1, last);
+			moveStack(w, 1, first, 1);
+			moveStack(w, n - 2, last, 1);
+		}
+	}
+	/*if (debug)
+		(void) printf("finishPart %d\n", (counter - start));*/
+}
+
+static void
+churn(PanexWidget w, int n, Boolean side, Boolean inv) {
+	int first, last;
+	/*int start = counter;*/
+	/*moves = 12 * 2^(n-2)*/
+
+	if (side) {
+		first = 2;
+		last  = 0;
+	} else {
+		first = 0;
+		last = 2;
+	}
+	if (inv) {
+		/* base free to combine */
+		moveATile(w, last, first);
+
+		moveStack(w, n - 1, 1, last);
+		moveATile(w, first, 1);
+		moveATile(w, first, 1);
+		moveStack(w, n - 1, last, first);
+		moveATile(w, 1, last);
+		moveATile(w, 1, last);
+		moveStack(w, n - 1, first, 1);
+
+		/* separate base */
+		moveATile(w, last, first);
+	} else {
+		/* base free to combine */
+		moveATile(w, first, last);
+
+		moveStack(w, n - 1, 1, first);
+		moveATile(w, last, 1);
+		moveATile(w, last, 1);
+		moveStack(w, n - 1, first, last);
+		moveATile(w, 1, first);
+		moveATile(w, 1, first);
+		moveStack(w, n - 1, last, 1);
+
+		/* separate base */
+		moveATile(w, first, last);
+	}
+	/*if (debug)
+		 (void) printf("churn %d\n", (counter - start)); */
+}
+
+static void
+A(PanexWidget w, int n, Boolean side, Boolean inv) {
+	int first, last;
+
+	if (side) {
+		first = 2;
+		last  = 0;
+	} else {
+		first = 0;
+		last = 2;
+	}
+	if (inv) {
+		if (n == 1) {
+			moveATile(w, last, 1);
+			moveATile(w, first, last);
+			moveATile(w, 1, first);
+		} else if (n == 2) {
+			startPart(w, n, side, !inv);
+			churn(w, n, side, !inv);
+			startPart(w, n, side, inv);
+		} else if (n > 2) {
+			finishPart(w, n, side, !inv);
+			churn(w, n, side, !inv);
+			startPart(w, n, side, inv);
+		}
+	} else {
+		if (n == 1) {
+			moveATile(w, first, 1);
+			moveATile(w, last, first);
+			moveATile(w, 1, last);
+		} else if (n == 2) {
+			startPart(w, n, side, inv);
+			churn(w, n, side, inv);
+			startPart(w, n, side, !inv);
+		} else if (n > 2) {
+			startPart(w, n, side, inv);
+			churn(w, n, side, inv);
+			finishPart(w, n, side, !inv);
+		}
+	}
+}
+
+static void
+solveAlgorithmeMode(PanexWidget w)
+{
+	if (solvingFlag)
+		return;
+#ifdef JMP
+	if (!setjmp(solve_env))
+#endif
+	{
+		solvingFlag = True;
+
+#ifdef WINVER
+		(void) SRAND(time(NULL));
+#else
+		(void) SRAND(getpid());
+#endif
+		if (w->panex.tiles > 0) {
+			Boolean side = (NRAND(2) == 1);
+			Boolean inv = (NRAND(2) == 1);
+#ifdef DEBUG
+			/* good for debugging */
+#if 1
+			Boolean side = LEFT;
+#else
+			Boolean side = RIGHT;
+#endif
+#if 1
+			Boolean side = NORMAL;
+#else
+			Boolean side = INVERSE;
+#endif
+#endif
+
+			if (w->panex.tiles > 0) {
+				A(w, w->panex.tiles, side, inv);
+			}
+		}
+	}
+#ifdef JMP
+	else {
+		drawAllTiles(w);
+	}
+	abortSolvingFlag = False;
+#endif
+	solvingFlag = False;
+	w->panex.cheat = True; /* Assume the worst. */
+	setPuzzle(w, ACTION_COMPUTED);
+#ifdef DEBUG
+	counter = 0;
+#endif
+}
+
 /*
 	Recursive algorithm starts at level 5, shown by computer checking
 	to be the shortest algorithm, i.e. the upper bound U(n), to at
@@ -1364,6 +1650,8 @@ solveTilesFromStart(PanexWidget w)
 {
 	if (w->panex.mode == PANEX)
 		solvePanexMode(w);
-	else
+	else if (w->panex.mode == ALGORITHME)
+		solveAlgorithmeMode(w);
+	else /*if (w->panex.mode == HANOI)*/
 		solveHanoiMode(w);
 }
