@@ -20,6 +20,131 @@
 
 /* Driver file for Panex */
 
+#ifndef WINVER
+static const char aboutHelp[] = {
+"Panex Version 7.4.2\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
+"I got some help from Rene Jansen <rene.j.jansen@bigfoot.com> "
+"and Nick Baxter <nickb@baxterweb.com>."
+};
+
+static const char optionsHelp[] = {
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-tile {color}] [-pyramid{0|1} {color}] [-delay msecs]\n"
+"[-[no]sound] [-moveSound {filename}]\n"
+"[-{font|fn} {fontname}]\n"
+"[-tiles {int}] [-{mode {int}|hanoi|algorithme|panex}]\n"
+"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+"[-version]"
+};
+#endif
+
+#if defined(HAVE_MOTIF) || defined(WINVER)
+static const char descriptionHelp[] = {
+"Panex - A grooved sliding tile puzzle created by Toshio "
+"Akanuma and manufactured by the Tricks Co., Ltd of Tokyo,\n"
+"Japan  (a Magic Company) in the 1980's.  Mathematicians at "
+"Bell Laboratories calculated the number of moves to be 27,564\n"
+"to 31,537.  It came in two varieties: one with a magenta and "
+"a orange pyramid of order 10 on silver tiles; in the gold\n"
+"version pieces of each color look alike (i.e. no pyramid is "
+"drawn on them), this is a little harder.  The goal in this\n"
+"puzzle is to simply exchange the 2 piles.  Pieces with "
+"smaller trapazoids can not go down as far as pieces with\n"
+"bigger trapazoids.\n"
+"\n"
+"The original Tower of Hanoi puzzle is the invention of "
+"Edouard Lucas and was sold as a toy in France in 1883.  The \n"
+"legend of 64 disks in the great temple of Benares of the god "
+"Brahma is also his invention.  The goal in this puzzle is to\n"
+"move the pile from the left side to the right most column.  "
+"Unlike panex, a large trapazoid can not go on top of a smaller\n"
+"one, but pieces always fall to the bottom.\n"
+"\n"
+"The original Algorithme 6 is 2 stacks of 3 wooden spheres on "
+"2 of 3 posts.  The spheres come in 3 different sizes.  The goal\n"
+"goal is to swap the spheres using the posts without putting a "
+"bigger sphere on a smaller one and without exceeding the\n"
+"size of the post.  It was created and produced by Patrick "
+"Farvacque around 1997.  The puzzle presented here has a\n"
+"simpler solution because the tiles are all the same height "
+"(i.e. a 39 move solution as opposed to 66).\n"
+};
+
+static const char featuresHelp[] = {
+"Press \"mouse-left\" button to move a tile in the top tile "
+"of a column.  Release \"mouse-left\" button on\n"
+"another column to move the tile to that column.  It will "
+"not move if blocked.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"C\" or \"c\" keys, "
+"to clear the puzzle.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save (write) a puzzle.\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"R\" or \"r\" keys to redo a move.\n"
+"\n"
+"Press \"S\" or \"s\" keys to auto-solve.  Unfortunately, its "
+"only implemented from the starting position.\n"
+"\n"
+"Press \"M\" or \"m\" keys to switch between Hanoi "
+"(one pyramid column), Algorithme and Panex (each has\n"
+"two pyramid columns) modes (they each have different rules).  "
+"In Hanoi, one can not place larger trapezoid on a smaller\n"
+"trapezoid.  Here the goal is to move the pile from the left " 
+"peg to the rightmost peg.  Algorithme is similar, here we\n"
+"must exchange tiles and we are limited by the size of the "
+"stack.  A move from stack 1 to stack 3 and vice-versa when\n"
+"stack 2 is full.  In Panex, a tile can not go lower that "
+"its initial starting point.  Here again, the goal is to\n"
+"exchange the 2 piles.\n"
+"\n"
+"Press \"I\" or \"i\" keys to increase the number of tiles.\n"
+"\n"
+"Press \"D\" or \"d\" keys to decrease the number of tiles.\n"
+"\n"
+"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
+"\n"
+"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
+"\n"
+"Press \"@\" key to toggle the sound.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Unlike other puzzles in the collection there is no way to "
+"move pieces without drag and drop."
+};
+
+static const char referencesHelp[] = {
+"Mark Manasse & Danny Sleator of AT&T Bell Laboratories  "
+"and Victor K. Wei of Bell Communications Research,\n"
+"Some Results on the Panex Puzzle, Murray Hill, NJ, 1985 "
+"20 pp. (unpublished).\n"
+"Vladimir Dubrovsky,  Nesting Puzzles  Part 1: Moving oriental "
+" Quantum  January/February  1996  pp 55-57,\n"
+"50-51.\n"
+"L.  E.  Horden,  Sliding  Piece  Puzzles  (Recreations  in  "
+"Mathematics  Series),  Oxford University Press  1986,\n"
+"pp 144, 145.\n"
+"Jerry Slocum & Jack Botermans,  Puzzles Old & New (How to Make "
+"and  Solve Them),  University of Washington\n"
+"Press, Seattle 1987, p 135.\n"
+"Dick Hess, Analysis of the Algorithme 6 Puzzle and its "
+"Generalisations, Cubism For Fun, July 2008 76 pp 8-13."
+};
+#endif
+
 #include "file.h"
 #ifdef WINVER
 #include "PanexP.h"
@@ -63,16 +188,25 @@ static PanexRec widget;
 #include "Panex.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "panex.t.xpm"
+#include "panex.p.xpm"
+#include "panex.s.xpm"
+#include "panex.m.xpm"
+#include "panex.l.xpm"
+#include "panex.xpm"
+#else
 #include "pixmaps/panex.t.xpm"
 #include "pixmaps/panex.p.xpm"
 #include "pixmaps/panex.s.xpm"
 #include "pixmaps/panex.m.xpm"
 #include "pixmaps/panex.l.xpm"
 #include "pixmaps/panex.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
 (((s)<=22)?(((s)<=16)?panex_t_xpm:panex_p_xpm):\
 (((s)<=24)?panex_s_xpm:panex_m_xpm)):\
-(((s)<=48)?panex_l_xpm:panex_xpm))
+(((s)<=48)?panex_l_xpm:panex_xpm)))
 #endif
 #include "pixmaps/panex.xbm"
 #define DEFINE_XBM (char *) panex_bits, panex_width, panex_height
@@ -85,109 +219,6 @@ static PanexRec widget;
 #endif
 #endif
 
-#ifndef WINVER
-static const char aboutHelp[] = {
-"Panex Version 7.4\n"
-"Send bugs (reports or fixes) to the author: "
-"David Bagley <bagleyd@tux.org>\n"
-"The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
-"I got some help from Rene Jansen <rene.j.jansen@bigfoot.com> "
-"and Nick Baxter <nickb@baxterweb.com>.\n"
-};
-
-static const char optionsHelp[] = {
-"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-"[-tile {color}] [-pyramid{0|1} {color}] [-delay msecs]\n"
-"[-[no]sound] [-moveSound {filename}]\n"
-"[-{font|fn} {fontname}]\n"
-"[-tiles {int}] [-{mode {int}|hanoi|panex}]\n"
-"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-"[-version]\n"
-};
-#endif
-
-#if defined(HAVE_MOTIF) || defined(WINVER)
-static const char descriptionHelp[] = {
-"The original Panex puzzle is from the Japanese Magic Company "
-"estimated from the 1980's.  Mathematicians at Bell\n"
-"Laboratories estimated the number of moves to swap 2 columns "
-"of order 10 to be  27,564 <= N <= 31,537.  It came\n"
-"in two varieties: one with a magenta and a orange pyramid "
-"of order 10 on silver tiles; in the gold version, the\n"
-"gold version pieces of each color look alike (i.e. no "
-"pyramid is drawn on them), this is a little harder.\n"
-"The original Tower of Hanoi puzzle is the invention of "
-"Edouard Lucas and temple of Benares of the god Brahma is\n"
-"also his invention.\n"
-};
-
-static const char featuresHelp[] = {
-"Press \"mouse-left\" button to move a tile in the top tile "
-"of a column.  Release \"mouse-left\" button on\n"
-"another column to move the tile to that column.  It will "
-"not move if blocked.\n"
-"\n"
-"Click \"mouse-right\" button, or press \"C\" or \"c\" keys, "
-"to clear the puzzle.\n"
-"\n"
-"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-"\n"
-"Press \"W\" or \"w\" keys to save (write) a puzzle.\n"
-"\n"
-"Press \"U\" or \"u\" keys to undo a move.\n"
-"\n"
-"Press \"R\" or \"r\" keys to redo a move.\n"
-"\n"
-"Press \"S\" or \"s\" keys to auto-solve.  Unfortunately, its "
-"only implemented from the starting position.\n"
-"\n"
-"Press \"M\" or \"m\" keys to toggle between hanoi "
-"(one pyramid column) and panex (two pyramid columns) modes\n"
-"(they each have different rules).\n"
-"In Hanoi, one can not place  larger trapezoid on a smaller "
-"trapezoid.  Here the goal is to move the pile from\n"
-"the left peg to the rightmost peg.\n"
-"In Panex, a tile can not go lower that its initial starting "
-"point.  Here the goal is to exchange the 2 piles.\n"
-"\n"
-"Press \"I\" or \"i\" keys to increase the number of tiles.\n"
-"\n"
-"Press \"D\" or \"d\" keys to decrease the number of tiles.\n"
-"\n"
-"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
-"\n"
-"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
-"\n"
-"Press \"@\" key to toggle the sound.\n"
-"\n"
-"Press \"Esc\" key to hide program.\n"
-"\n"
-"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-"\n"
-"Unlike other puzzles in the collection there is no way to "
-"move pieces without drag and drop.\n"
-};
-
-static const char referencesHelp[] = {
-"Mark Manasse & Danny Sleator of AT&T Bell Laboratories  "
-"and Victor K. Wei of Bell Communications Research,\n"
-"Some Results on the Panex Puzzle, Murray Hill, NJ, 1985 "
-"20 pp. (unpublished).\n"
-"Vladimir Dubrovsky,  Nesting Puzzles  Part 1: Moving oriental "
-" Quantum  January/February  1996  pp 55-57,\n"
-"50-51.\n"
-"L.  E.  Horden,  Sliding  Piece  Puzzles  (Recreations  in  "
-"Mathematics  Series),  Oxford University Press  1986,\n"
-"pp 144, 145.\n"
-"Jerry Slocum & Jack Botermans,  Puzzles Old & New (How to Make "
-"and  Solve Them),  University of Washington\n"
-"Press, Seattle 1987, p 135.\n"
-};
-#endif
-
 #ifndef SCOREFILE
 #define SCOREFILE "panex.scores"
 #endif
@@ -219,7 +250,7 @@ static Widget tileSlider, speedSlider;
 static char buff[21];
 static const char *modeString[] =
 {
-	"Hanoi", "Panex"
+	"Hanoi", "Algorithme", "Panex"
 };
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -258,7 +289,7 @@ printRecords(void)
 {
 	int i, mode;
 
-	(void) printf("   HANOI/PANEX  HALL OF FAME\n\n");
+	(void) printf("HANOI/ALGORITHME/PANEX  HALL OF FAME\n\n");
 	(void) printf("PANEX TILES USER            MOVES\n");
 	for (mode = 0; mode < MAX_MODES; mode++)
 		for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
@@ -483,7 +514,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -659,7 +690,9 @@ puzzleListener(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 		break;
 	case ACTION_MODE:
 		movesDsp = 0;
-		mode = (mode == PANEX) ? HANOI : PANEX;
+		mode++;
+		if (mode > PANEX)
+			mode = HANOI;
 		printRecord(tiles, mode);
 #ifdef WINVER
 		w->panex.mode = mode;
@@ -944,6 +977,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -971,7 +1005,8 @@ static XrmOptionDescRec options[] =
 	{(char *) "-tiles", (char *) "*panex.tiles", XrmoptionSepArg, NULL},
 	{(char *) "-mode", (char *) "*panex.mode", XrmoptionSepArg, NULL},
 	{(char *) "-hanoi", (char *) "*panex.mode", XrmoptionNoArg, (char *) "0"},
-	{(char *) "-panex", (char *) "*panex.mode", XrmoptionNoArg, (char *) "1"},
+	{(char *) "-algorithme", (char *) "*panex.mode", XrmoptionNoArg, (char *) "1"},
+	{(char *) "-panex", (char *) "*panex.mode", XrmoptionNoArg, (char *) "2"},
 	{(char *) "-userName", (char *) "*panex.userName", XrmoptionSepArg, NULL},
 	{(char *) "-scoreFile", (char *) "*panex.scoreFile", XrmoptionSepArg, NULL},
 	{(char *) "-scores", (char *) "*panex.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
@@ -1067,7 +1102,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1093,7 +1128,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1198,7 +1233,7 @@ main(int argc, char **argv)
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
 	solveString = XmStringCreateSimple((char *) "Auto-Solve");
-	mode = XmStringCreateSimple((char *) "Mode (Hanoi/Panex)");
+	mode = XmStringCreateSimple((char *) "Mode (Hanoi/Algorithme/Panex)");
 	incrementString = XmStringCreateSimple((char *) "Increment");
 	decrementString = XmStringCreateSimple((char *) "Decrement");
 	speedString = XmStringCreateSimple((char *) ">Speed");
@@ -1237,7 +1272,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
