@@ -2311,7 +2311,7 @@ randomizePieces(PyraminxWidget w)
 static void
 solvePieces(PyraminxWidget w)
 {
-	if (checkSolved(w) && w->pyraminx.currentFace > IGNORE_DIR)
+	if (checkSolved(w) || w->pyraminx.currentFace > IGNORE_DIR)
 		return;
 	if ((w->pyraminx.size == 2 || w->pyraminx.size == 3) &&
 			w->pyraminx.mode == PERIOD3)
