@@ -20,78 +20,13 @@
 
 /* Driver file for Pyraminx */
 
-#include "file.h"
-#ifdef WINVER
-#include "PyraminxP.h"
-#define TITLE "wpyraminx"
-
-static PyraminxRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->pyraminx.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#include <Xm/ToggleB.h>
-#include <Xm/ToggleBG.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Pyraminx.h"
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/pyraminx.t.xpm"
-#include "pixmaps/pyraminx.p.xpm"
-#include "pixmaps/pyraminx.s.xpm"
-#include "pixmaps/pyraminx.m.xpm"
-#include "pixmaps/pyraminx.l.xpm"
-#include "pixmaps/pyraminx.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?pyraminx_t_xpm:pyraminx_p_xpm):\
-(((s)<=24)?pyraminx_s_xpm:pyraminx_m_xpm)):\
-(((s)<=48)?pyraminx_l_xpm:pyraminx_xpm))
-#endif
-#include "pixmaps/pyraminx.xbm"
-#define DEFINE_XBM (char *) pyraminx_bits, pyraminx_width, pyraminx_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Pyraminx Version 7.4\n"
+"Pyraminx Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -103,7 +38,7 @@ static const char optionsHelp[] = {
 "[-{font|fn} {fontname}] [-{size {int} | sticky}]\n"
 "[-{mode {int} | both}] [-[no]orient] [-[no]practice]\n"
 "[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-"[-version]\n"
+"[-version]"
 };
 #endif
 
@@ -137,7 +72,7 @@ static const char descriptionHelp[] = {
 "One is able to simulate Halpern's Tetrahedron or Pyraminx "
 "Tetrahedron (period 3 turning and sticky mode).   Also one\n"
 "is able to simulate one with variant turning (period 2 "
-"turning and sticky mode).\n"
+"turning and sticky mode)."
 };
 
 static const char featuresHelp[] = {
@@ -221,7 +156,7 @@ static const char featuresHelp[] = {
 "\n"
 "Use the control key and the left mouse button, keypad, or "
 "arrow keys to move the whole tetrahedron.  This is not\n"
-"recorded as a turn.\n"
+"recorded as a turn."
 };
 
 static const char referencesHelp[] = {
@@ -234,15 +169,89 @@ static const char referencesHelp[] = {
 "July 1982, pp 16-31.\n"
 "John Ewing & Czes Kosniowski, Puzzle it Out: Cubes Groups and "
 "Puzzles, Cambridge University Press, New York, 1982, pp 60-61.\n"
-"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
+"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow."
 };
 #endif
 
 static const char solveHelp[] = {
 "Auto-solver: sorry, only implemented for size < 4 where "
-"period = 3.\n"
+"period = 3."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "PyraminxP.h"
+#define TITLE "wpyraminx"
+
+static PyraminxRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->pyraminx.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#include <Xm/ToggleB.h>
+#include <Xm/ToggleBG.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Pyraminx.h"
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "pyraminx.t.xpm"
+#include "pyraminx.p.xpm"
+#include "pyraminx.s.xpm"
+#include "pyraminx.m.xpm"
+#include "pyraminx.l.xpm"
+#include "pyraminx.xpm"
+#else
+#include "pixmaps/pyraminx.t.xpm"
+#include "pixmaps/pyraminx.p.xpm"
+#include "pixmaps/pyraminx.s.xpm"
+#include "pixmaps/pyraminx.m.xpm"
+#include "pixmaps/pyraminx.l.xpm"
+#include "pixmaps/pyraminx.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?pyraminx_t_xpm:pyraminx_p_xpm):\
+(((s)<=24)?pyraminx_s_xpm:pyraminx_m_xpm)):\
+(((s)<=48)?pyraminx_l_xpm:pyraminx_xpm)))
+#endif
+#include "pixmaps/pyraminx.xbm"
+#define DEFINE_XBM (char *) pyraminx_bits, pyraminx_width, pyraminx_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "pyraminx.scores"
 #endif
@@ -580,7 +589,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -1284,6 +1293,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1511,7 +1521,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1537,7 +1547,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1692,7 +1702,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
