@@ -1,27 +1,22 @@
-/*-
-# X-BASED RUBIK'S CUBE(tm)
-#
-#  Rubik2d.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Rubik2d.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Rubik2d */
 
@@ -29,20 +24,20 @@
 #include "Rubik2dP.h"
 
 #ifndef WINVER
-static Boolean SetValuesPuzzle2D(Widget current, Widget request, Widget renew);
-static void ResizePuzzle2D(Rubik2DWidget w);
-static void InitializePuzzle2D(Widget request, Widget renew);
-static void ExposePuzzle2D(Widget renew, XEvent *event, Region region);
-static void MovePuzzle2DTop(Rubik2DWidget w,
+static Boolean setValuesPuzzle2D(Widget current, Widget request, Widget renew);
+static void resizePuzzle2D(Rubik2DWidget w);
+static void initializePuzzle2D(Widget request, Widget renew);
+static void exposePuzzle2D(Widget renew, XEvent *event, Region region);
+static void movePuzzle2DTop(Rubik2DWidget w,
 			   XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DLeft(Rubik2DWidget w,
+static void movePuzzle2DLeft(Rubik2DWidget w,
 			    XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DRight(Rubik2DWidget w,
+static void movePuzzle2DRight(Rubik2DWidget w,
 			     XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DBottom(Rubik2DWidget w,
+static void movePuzzle2DBottom(Rubik2DWidget w,
 			      XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzle2D[] =
+static char translations2D[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -106,45 +101,45 @@ static char defaultTranslationsPuzzle2D[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzle2D[] =
+static XtActionsRec actionsList2D[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveCcw", (XtActionProc) MovePuzzleCcw},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzle2DTop},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzle2DLeft},
-	{(char *) "MoveCw", (XtActionProc) MovePuzzleCw},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzle2DRight},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzle2DBottom},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Increment", (XtActionProc) IncrementPuzzle},
-	{(char *) "Decrement", (XtActionProc) DecrementPuzzle},
-	{(char *) "IncrementX", (XtActionProc) IncrementXPuzzle},
-	{(char *) "IncrementY", (XtActionProc) IncrementYPuzzle},
-	{(char *) "IncrementZ", (XtActionProc) IncrementZPuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-        {(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveCcw", (XtActionProc) movePuzzleCcw},
+	{(char *) "MoveTop", (XtActionProc) movePuzzle2DTop},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzle2DLeft},
+	{(char *) "MoveCw", (XtActionProc) movePuzzleCw},
+	{(char *) "MoveRight", (XtActionProc) movePuzzle2DRight},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzle2DBottom},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Increment", (XtActionProc) incrementPuzzle},
+	{(char *) "Decrement", (XtActionProc) decrementPuzzle},
+	{(char *) "IncrementX", (XtActionProc) incrementXPuzzle},
+	{(char *) "IncrementY", (XtActionProc) incrementYPuzzle},
+	{(char *) "IncrementZ", (XtActionProc) incrementZPuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+        {(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzle2D[] =
+static XtResource resources2D[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(RubikWidget, core.width),
@@ -163,7 +158,7 @@ static XtResource resourcesPuzzle2D[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
@@ -268,29 +263,29 @@ Rubik2DClassRec rubik2dClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle2D,	/* initialize */
+		(XtInitProc) initializePuzzle2D,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzle2D,	/* actions */
-		XtNumber(actionsListPuzzle2D),	/* num actions */
-		resourcesPuzzle2D,	/* resources */
-		XtNumber(resourcesPuzzle2D),	/* num resources */
+		actionsList2D,	/* actions */
+		XtNumber(actionsList2D),	/* num actions */
+		resources2D,	/* resources */
+		XtNumber(resources2D),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzle2D,	/* resize */
-		(XtExposeProc) ExposePuzzle2D,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle2D,	/* set values */
+		(XtWidgetProc) resizePuzzle2D,	/* resize */
+		(XtExposeProc) exposePuzzle2D,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzle2D,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzle2D,	/* tm table */
+		translations2D,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -323,7 +318,7 @@ static int  cubeToPlane[MAX_FACES] =
 static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
-FacePosition(Rubik2DWidget w, int faceX, int faceY,
+facePosition(Rubik2DWidget w, int faceX, int faceY,
 	     int *viewLengthx, int *viewLengthy)
 {
 	int         i;
@@ -347,7 +342,7 @@ FacePosition(Rubik2DWidget w, int faceX, int faceY,
 }
 
 static void
-DrawOrientLine(Rubik2DWidget w, int orient, int dx, int dy, GC borderGC)
+drawOrientLine(Rubik2DWidget w, int orient, int dx, int dy, GC borderGC)
 {
 	switch (orient) {
 	case TOP:
@@ -384,7 +379,7 @@ DrawOrientLine(Rubik2DWidget w, int orient, int dx, int dy, GC borderGC)
 		{
 			char *buf;
 
-			intCat(&buf, "DrawOrientLine: orient ",
+			intCat(&buf, "drawOrientLine: orient ",
 				orient);
 			DISPLAY_WARNING(buf);
 			free(buf);
@@ -393,7 +388,7 @@ DrawOrientLine(Rubik2DWidget w, int orient, int dx, int dy, GC borderGC)
 }
 
 void
-DrawSquare2D(Rubik2DWidget w, int face, int position, int offset)
+drawSquare2D(Rubik2DWidget w, int face, int position, int offset)
 {
 	GC faceGC, borderGC;
 	int dx, dy, orient, i, j, sizeOfRow, sizeOfColumn;
@@ -403,13 +398,13 @@ DrawSquare2D(Rubik2DWidget w, int face, int position, int offset)
 	j = position / sizeOfRow;
 	orient = w->rubik.cubeLoc[face][position].rotation;
 	if (w->rubik.vertical || face != MAX_FACES - 1) {
-		FacePosition(w,
+		facePosition(w,
 			cubeToPlane[face] % MAXX, cubeToPlane[face] / MAXX,
 			&dx, &dy);
 		dx += i * (w->rubik2d.cubeLength + w->rubik.delta - 1);
 		dy += j * (w->rubik2d.cubeLength + w->rubik.delta - 1);
 	} else {
-		FacePosition(w,
+		facePosition(w,
 			cubeToPlane[face] / MAXX, cubeToPlane[face] % MAXX,
 			&dx, &dy);
 		dx += (sizeOfRow - 1 - i) *
@@ -458,11 +453,11 @@ DrawSquare2D(Rubik2DWidget w, int face, int position, int offset)
 		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->rubik.orient)
-		DrawOrientLine(w, orient, dx, dy, borderGC);
+		drawOrientLine(w, orient, dx, dy, borderGC);
 }
 
 void
-DrawFrame2D(Rubik2DWidget w, Boolean focus)
+drawFrame2D(Rubik2DWidget w, Boolean focus)
 {
 	int i;
 	Point tempLength;
@@ -511,7 +506,7 @@ DrawFrame2D(Rubik2DWidget w, Boolean focus)
 }
 
 static void
-ResizeCubie(Rubik2DWidget w)
+resizeCubie(Rubik2DWidget w)
 {
 	Point flatlength, flatlengthh;
 	int tempLength;
@@ -541,16 +536,16 @@ ResizeCubie(Rubik2DWidget w)
 }
 
 static void
-ResizePieces(Rubik2DWidget w)
+resizePieces(Rubik2DWidget w)
 {
-	ResizeCubie(w);
+	resizeCubie(w);
 	w->rubik.orientLineLength = w->rubik2d.cubeLength / 4;
 	w->rubik.letterOffset.x = -2;
 	w->rubik.letterOffset.y = 4;
 }
 
 Boolean
-SelectPieces2D(Rubik2DWidget w, int x, int y, int *face, int *position)
+selectPieces2D(Rubik2DWidget w, int x, int y, int *face, int *position)
 {
 	int faceX, faceY, i, j, sizeOfRow, sizeOfColumn, tempLength;
 
@@ -604,7 +599,7 @@ SelectPieces2D(Rubik2DWidget w, int x, int y, int *face, int *position)
 }
 
 Boolean
-NarrowSelection2D(Rubik2DWidget w, int *face, int *position, int *direction)
+narrowSelection2D(Rubik2DWidget w, int *face, int *position, int *direction)
 {
 	if (*face == MAX_FACES - 1 && *direction < MAX_ORIENT && !w->rubik.vertical)
 		*direction = (*direction + HALF) % MAX_ORIENT;
@@ -632,7 +627,7 @@ NarrowSelection2D(Rubik2DWidget w, int *face, int *position, int *direction)
 
 #ifndef WINVER
 static Boolean
-SetValuesPuzzle2D(Widget current, Widget request, Widget renew)
+setValuesPuzzle2D(Widget current, Widget request, Widget renew)
 {
 	Rubik2DWidget c = (Rubik2DWidget) current, w = (Rubik2DWidget) renew;
 	Boolean redraw = False;
@@ -640,12 +635,12 @@ SetValuesPuzzle2D(Widget current, Widget request, Widget renew)
 	if (w->rubik.sizex != c->rubik.sizex ||
 			w->rubik.sizey != c->rubik.sizey ||
 			w->rubik.sizez != c->rubik.sizez) {
-		ResetPieces((RubikWidget) w);
-		ResizePuzzle2D(w);
+		resetPieces((RubikWidget) w);
+		resizePuzzle2D(w);
 		redraw = True;
 	}
 	if (w->rubik2d.cubeLength != c->rubik2d.cubeLength) {
-		ResizePuzzle2D(w);
+		resizePuzzle2D(w);
 		redraw = True;
 	}
 	return (redraw);
@@ -656,7 +651,7 @@ SetValuesPuzzle2D(Widget current, Widget request, Widget renew)
 static
 #endif
 void
-ResizePuzzle2D(Rubik2DWidget w)
+resizePuzzle2D(Rubik2DWidget w)
 {
 #ifdef WINVER
 	RECT rect;
@@ -667,7 +662,7 @@ ResizePuzzle2D(Rubik2DWidget w)
 	w->core.height = rect.bottom;
 #endif
 
-	ResizeCubie(w);
+	resizeCubie(w);
 	if (w->rubik.vertical) {
 		w->rubik.puzzleSize.x = (w->rubik2d.viewLengthx - 1) +
 			2 * (w->rubik2d.viewLengthz - 1) + w->rubik.delta;
@@ -683,14 +678,14 @@ ResizePuzzle2D(Rubik2DWidget w)
 		/ 2;
 	w->rubik.puzzleOffset.y = ((int) w->core.height - w->rubik.puzzleSize.y)
 		/ 2;
-	ResizePieces(w);
+	resizePieces(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-InitializePuzzle2D(
+initializePuzzle2D(
 #ifdef WINVER
 Rubik2DWidget w
 #else
@@ -701,17 +696,17 @@ Widget request, Widget renew
 #ifndef WINVER
 	Rubik2DWidget w = (Rubik2DWidget) renew;
 
-	SetAllColors((RubikWidget) w);
+	setAllColors((RubikWidget) w);
 #endif
 	w->rubik.dim = 2;
-	ResizePuzzle2D(w);
+	resizePuzzle2D(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-ExposePuzzle2D(
+exposePuzzle2D(
 #ifdef WINVER
 Rubik2DWidget w
 #else
@@ -727,36 +722,36 @@ Widget renew, XEvent *event, Region region
 #endif
 	FILLRECTANGLE(w, dr, w->rubik.inverseGC,
 		0, 0, w->core.width, w->core.height);
-	DrawFrame2D(w, w->rubik.focus);
-	DrawAllPieces((RubikWidget) w);
+	drawFrame2D(w, w->rubik.focus);
+	drawAllPieces((RubikWidget) w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzle2DTop(Rubik2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DTop(Rubik2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle2DLeft(Rubik2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DLeft(Rubik2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle2DRight(Rubik2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DRight(Rubik2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle2DBottom(Rubik2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DBottom(Rubik2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM, (int) (event->xkey.state & ControlMask));
 }
 #endif
