@@ -20,82 +20,13 @@
 
 /* Driver file for Rubik */
 
-#include "file.h"
-#ifdef WINVER
-#include "RubikP.h"
-#define TITLE "wrubik"
-
-static RubikRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->rubik.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#include <Xm/ToggleB.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Rubik.h"
-#include "Rubik2d.h"
-#include "Rubik3d.h"
-#ifdef HAVE_OPENGL
-#include "RubikGL.h"
-#endif
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/rubik.t.xpm"
-#include "pixmaps/rubik.p.xpm"
-#include "pixmaps/rubik.s.xpm"
-#include "pixmaps/rubik.m.xpm"
-#include "pixmaps/rubik.l.xpm"
-#include "pixmaps/rubik.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?rubik_t_xpm:rubik_p_xpm):\
-(((s)<=24)?rubik_s_xpm:rubik_m_xpm)):\
-(((s)<=48)?rubik_l_xpm:rubik_xpm))
-#endif
-#include "pixmaps/rubik.xbm"
-#define DEFINE_XBM (char *) rubik_bits, rubik_width, rubik_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Rubik Version 7.4\n"
+"Rubik Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -106,7 +37,7 @@ static const char optionsHelp[] = {
 "[-delay msecs] [-[no]sound] [-moveSound {filename}]\n"
 "[-{font|fn} {fontname}] [-view {int}] [-size{x|y|z} {int}]\n"
 "[-[no]orient] [-[no]practice] [-userName {string}]\n"
-"[-scoreFile {filename}] [-scores] [-version]\n"
+"[-scoreFile {filename}] [-scores] [-version]"
 };
 #endif
 
@@ -130,7 +61,7 @@ static const char descriptionHelp[] = {
 "one has been too successful in building one.  7x7x7 is\n"
 "also possible, but here one  must make the center most "
 "cubes smaller than the  outside cubes, so the corners do\n"
-"not fall off when turned.\n"
+"not fall off when turned."
 };
 
 static const char featuresHelp[] = {
@@ -220,7 +151,7 @@ static const char featuresHelp[] = {
 "\n"
 "Use the control key and the left mouse button, keypad, or "
 "arrow keys to move the whole cube.  This is\n"
-"not recorded as a turn.\n"
+"not recorded as a turn."
 };
 
 static const char referencesHelp[] = {
@@ -232,15 +163,93 @@ static const char referencesHelp[] = {
 "Rubik's Cube Newsletter by Ideal Aug 1982 Vol.1 No. 2.\n"
 "Rubik's Cube The Solution, Ideal Toy Corporation, 1981.\n"
 "Rubik's Revenge Puzzle The Solution, Ideal Toy "
-"Corporation, 1982.\n"
+"Corporation, 1982."
 };
 #endif
 
 static const char solveHelp[] = {
 "Auto-solver: sorry, only implemented for size nxnxn where "
-"n < 4.\n"
+"n < 4."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "RubikP.h"
+#define TITLE "wrubik"
+
+static RubikRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->rubik.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#include <Xm/ToggleB.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Rubik.h"
+#include "Rubik2d.h"
+#include "Rubik3d.h"
+#ifdef HAVE_OPENGL
+#include "RubikGL.h"
+#endif
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "rubik.t.xpm"
+#include "rubik.p.xpm"
+#include "rubik.s.xpm"
+#include "rubik.m.xpm"
+#include "rubik.l.xpm"
+#include "rubik.xpm"
+#else
+#include "pixmaps/rubik.t.xpm"
+#include "pixmaps/rubik.p.xpm"
+#include "pixmaps/rubik.s.xpm"
+#include "pixmaps/rubik.m.xpm"
+#include "pixmaps/rubik.l.xpm"
+#include "pixmaps/rubik.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?rubik_t_xpm:rubik_p_xpm):\
+(((s)<=24)?rubik_s_xpm:rubik_m_xpm)):\
+(((s)<=48)?rubik_l_xpm:rubik_xpm)))
+#endif
+#include "pixmaps/rubik.xbm"
+#define DEFINE_XBM (char *) rubik_bits, rubik_width, rubik_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "rubik.scores"
 #endif
@@ -548,7 +557,7 @@ makeEquivalent(String *userName, String *scoreFile,
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(*scoreFile, ""))
@@ -1720,6 +1729,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1976,7 +1986,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -2002,7 +2012,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
