@@ -20,81 +20,13 @@
 
 /* Driver file for Skewb */
 
-#include "file.h"
-#ifdef WINVER
-#include "SkewbP.h"
-#define TITLE "wskewb"
-
-static SkewbRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->skewb.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/ToggleB.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Skewb.h"
-#include "Skewb2d.h"
-#include "Skewb3d.h"
-#ifdef HAVE_OPENGL
-#include "SkewbGL.h"
-#endif
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/skewb.t.xpm"
-#include "pixmaps/skewb.p.xpm"
-#include "pixmaps/skewb.s.xpm"
-#include "pixmaps/skewb.m.xpm"
-#include "pixmaps/skewb.l.xpm"
-#include "pixmaps/skewb.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?skewb_t_xpm:skewb_p_xpm):\
-(((s)<=24)?skewb_s_xpm:skewb_m_xpm)):\
-(((s)<=48)?skewb_l_xpm:skewb_xpm))
-#endif
-#include "pixmaps/skewb.xbm"
-#define DEFINE_XBM (char *) skewb_bits, skewb_width, skewb_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Skewb Version 7.4\n"
+"Skewb Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -105,7 +37,7 @@ static const char optionsHelp[] = {
 "[-delay msecs] [-[no]sound] [-moveSound {filename}]\n"
 "[-{font|fn} {fontname}] [-view {int}] [-[no]orient]\n"
 "[-[no]practice] [-userName {string}]\n"
-"[-scoreFile {filename}] [-scores] [-version]\n"
+"[-scoreFile {filename}] [-scores] [-version]"
 };
 #endif
 
@@ -215,7 +147,7 @@ static const char featuresHelp[] = {
 "\n"
 "Use the control key and the left mouse button, keypad, or "
 "arrow keys to move the whole cube.  This is\n"
-"not recorded as a turn.\n"
+"not recorded as a turn."
 };
 
 static const char referencesHelp[] = {
@@ -223,14 +155,91 @@ static const char referencesHelp[] = {
 "God knows what else by Douglas\n"
 "R. Hofstadter, Scientific American, July 1982, pp 16-31.\n"
 "Mickey's Challenge by Christoph Bandelow.\n"
-"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
+"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow."
 };
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "SkewbP.h"
+#define TITLE "wskewb"
+
+static SkewbRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->skewb.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/ToggleB.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Skewb.h"
+#include "Skewb2d.h"
+#include "Skewb3d.h"
+#ifdef HAVE_OPENGL
+#include "SkewbGL.h"
+#endif
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "skewb.t.xpm"
+#include "skewb.p.xpm"
+#include "skewb.s.xpm"
+#include "skewb.m.xpm"
+#include "skewb.l.xpm"
+#include "skewb.xpm"
+#else
+#include "pixmaps/skewb.t.xpm"
+#include "pixmaps/skewb.p.xpm"
+#include "pixmaps/skewb.s.xpm"
+#include "pixmaps/skewb.m.xpm"
+#include "pixmaps/skewb.l.xpm"
+#include "pixmaps/skewb.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?skewb_t_xpm:skewb_p_xpm):\
+(((s)<=24)?skewb_s_xpm:skewb_m_xpm)):\
+(((s)<=48)?skewb_l_xpm:skewb_xpm)))
+#endif
+#include "pixmaps/skewb.xbm"
+#define DEFINE_XBM (char *) skewb_bits, skewb_width, skewb_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "skewb.scores"
 #endif
@@ -477,7 +486,7 @@ makeEquivalent(String *userName, String *scoreFile,
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(*scoreFile, ""))
@@ -1402,6 +1411,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1539,7 +1549,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1565,7 +1575,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
