@@ -279,7 +279,7 @@ static XtResource resourcesThreeD[] = {
 	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_SURFACE */
 	{XtNobject, XtCObject, XtRInt, sizeof (int),
 	 XtOffset(ThreeDWidget, threed.object),
-	 XtRString, (caddr_t) "0"},
+	 XtRString, (caddr_t) "6"},
 	{XtNobjectName, XtCObjectName, XtRString, sizeof (String),
 	 XtOffset(ThreeDWidget, threed.name),
 	 XtRString, (caddr_t) "None"},
@@ -550,12 +550,10 @@ drawObject(ThreeDWidget w, Object3D *obj)
 {
 	int surf, vert, vertex, mapIndex, clickSurface = -1;
 	Point points[MAX_POLYGON_VERTICES + 1];
-	Point thePoints[MAX_POLYGON_VERTICES + 1];
 	Pixmap *dr;
 	double s1 = 0.0, s2 = 0.0, s3 = 0.0;
 	Point3D *v1, *v2, *v3;
-	GC lineGC, fillGC, theFillGC = NULL;
-	int theVert = -1;
+	GC lineGC, fillGC;
 
 	dr = &(w->threed.bufferObjects[0]);
 	/* compute position of object in world */
@@ -622,21 +620,18 @@ drawObject(ThreeDWidget w, Object3D *obj)
 		}
 		points[vert].x = points[0].x;
 		points[vert].y = points[0].y;
-		if (surf == clickSurface) {
-			theFillGC = w->threed.shadeGC[obj->surface[surf].color];
+		if (clickSurface >= 0 && obj->surface[surf].depthIndex ==
+				obj->surface[clickSurface].depthIndex) {
 			fillGC = w->threed.frameGC;
 			lineGC = w->threed.frameGC;
-			for (theVert = 0; theVert <= obj->surface[surf].numVertices;
-					theVert++) {
-				thePoints[theVert].x = points[theVert].x;
-				thePoints[theVert].y = points[theVert].y;
-			}
 		} else {
 			fillGC = w->threed.shadeGC[obj->surface[surf].color];
 			lineGC = w->threed.shadeGC[obj->surface[surf].color];
 		}
 		if (!w->threed.surface || obj->surface[surf].visible == 0) {
-			if (surf != clickSurface) {
+			if (clickSurface < 0 ||
+					obj->surface[surf].depthIndex !=
+					obj->surface[clickSurface].depthIndex) {
 				POLYLINE(w, *dr, fillGC,
 					&points[0], vert + 1, True);
 			}
@@ -666,10 +661,34 @@ drawObject(ThreeDWidget w, Object3D *obj)
 #endif
 		}
 	}
-	if (theVert > 0) {
-		POLYLINE(w, *dr, (w->threed.surface && theFillGC != NULL) ?
-			theFillGC : w->threed.frameGC,
-			&thePoints[0], theVert, True);
+	for (surf = 0; surf < obj->numSurfaces; surf++) {
+		mapIndex = obj->surface[surf].mapIndex;
+		if (obj->surface[surf].visible == -1 ||
+				obj->surface[surf].clipped)
+			continue;
+		for (vert = 0; vert < obj->surface[surf].numVertices;
+				vert++, mapIndex++) {
+			vertex = obj->map[mapIndex];
+			if (vert < MAX_POLYGON_VERTICES) {
+				/* Its not dynamic but we are really after
+				   speed here */
+				points[vert].x = obj->vertex[vertex].screen.x;
+				points[vert].y = obj->vertex[vertex].screen.y;
+			} else {
+				break;
+			}
+		}
+		points[vert].x = points[0].x;
+		points[vert].y = points[0].y;
+		if (clickSurface >= 0 && obj->surface[surf].depthIndex ==
+				obj->surface[clickSurface].depthIndex) {
+			fillGC = w->threed.frameGC;
+			lineGC = w->threed.shadeGC[obj->surface[surf].color];
+			POLYLINE(w, *dr,
+				(w->threed.surface && lineGC != NULL) ?
+				lineGC : w->threed.frameGC,
+				&points[0], vert + 1, True);
+		}
 	}
 #ifdef USE_SOUND
 	if (w->threed.sound) {
@@ -914,7 +933,7 @@ static void
 readCommon(ThreeDWidget w, FILE *fp, char *buffer)
 {
 	char *string;
-	int i, j, k, l, depthIndex;
+	int i, j, k, l;
 	double scale;
 
 	string = readLine(fp, buffer, SYMBOL);
@@ -1039,8 +1058,7 @@ readCommon(ThreeDWidget w, FILE *fp, char *buffer)
 				while (*str != ' ' &&
 						*str != '\t' && *str != '\0')
 					str++;
-				(void) sscanf(str, "%d", &(obj->map[l]));
-				obj->map[l++]--;
+				(void) sscanf(str, "%d", &(obj->map[l++]));
 				if (*str != '\0')
 					str++;
 			}
@@ -1064,26 +1082,17 @@ readCommon(ThreeDWidget w, FILE *fp, char *buffer)
 		for (j = 0; j < obj->numSurfaces; j++) {
 			(void) sscanf(string, "%d %d %d",
 				&(obj->surface[j].mapIndex),
-				&depthIndex,
+				&(obj->surface[j].depthIndex),
 				&(obj->surface[j].color));
 			if (j < obj->numSurfaces - 1)
 				string = readLine(fp, buffer, '\0');
-#ifdef DEPTHINDEX
-			obj->surface[j].depthIndex = depthIndex;
-#else
-			depthIndex = 0;
-#endif
 		}
 #ifdef DEBUG
 		(void) fprintf(stderr, "\nSURFACES%c\n", SYMBOL);
 		for (j = 0; j < obj->numSurfaces; j++)
 			(void) fprintf(stderr, "%d\t%d\t%d\n",
 				obj->surface[j].mapIndex,
-#ifdef DEPTHINDEX
 				obj->surface[j].depthIndex,
-#else
-				depthIndex,
-#endif
 				obj->surface[j].color);
 #endif
 		for (j = 0; j < obj->numSurfaces; j++) {
