@@ -22,13 +22,13 @@
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Threed Version 7.4\n"
+"Threed Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
 "http://www.tux.org/~bagleyd/puzzles.html\n"
 "Originally written by Thomas W. Olsen "
-"in the \"The C Users Journal\".\n"
+"in the \"The C Users Journal\"."
 };
 
 static const char optionsHelp[] = {
@@ -40,7 +40,7 @@ static const char optionsHelp[] = {
 "[-[no]sound] [-bumpSound {filename}]\n"
 "[-moveSound {filename}] [-[no]surface]\n"
 "[-object {int}] [-x {int}] [-y {int}] [-z {int}]\n"
-"[-theta {int}] [-phi {int}] [psi {int}] [-version]\n"
+"[-theta {int}] [-phi {int}] [psi {int}] [-version]"
 };
 #endif
 
@@ -94,14 +94,14 @@ static const char featuresHelp[] = {
 "I think the roll part is not quite right as it does\n"
 "not track well.\n"
 "In the sample data, Cubes and F16 are big, so the "
-"polyhedrons are scaled up to them in the data file.\n"
+"polyhedrons are scaled up to them in the data file."
 };
 
 static const char referencesHelp[] = {
 "Original code by\n"
 "Thomas W. Olsen \"The C Users Journal\".\n"
 "Andre LaMothe \"Black Art of 3D Game Programming\".\n"
-"Arash Partow \"http://www.partow.net\".\n"
+"Arash Partow \"http://www.partow.net\"."
 };
 #endif
 
@@ -139,12 +139,14 @@ setThreed(ThreeDWidget w, int reason)
 		break;
 	case ACTION_OBJECT:
 		hMenu = GetMenu(w->core.hWnd);
-		(void) CheckMenuItem(hMenu, (unsigned int)
-			w->threed.object + ACTION_TETRA, MF_UNCHECKED);
-		w->threed.object = (w->threed.object + 1) %
-			w->threed.numObjects;
-		(void) CheckMenuItem(hMenu, (unsigned int)
-			w->threed.object + ACTION_TETRA, MF_CHECKED);
+		if (w->threed.numObjects > 0) {
+			(void) CheckMenuItem(hMenu, (unsigned int)
+				w->threed.object + ACTION_TETRA, MF_UNCHECKED);
+			w->threed.object = (w->threed.object + 1) %
+				w->threed.numObjects;
+			(void) CheckMenuItem(hMenu, (unsigned int)
+				w->threed.object + ACTION_TETRA, MF_CHECKED);
+		}
 		break;
 	}
 }
@@ -273,8 +275,10 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_DODECA:
 		case ACTION_ICOSA:
 		case ACTION_RHOMBIC:
-		case ACTION_CONTA:
-		case ACTION_CUBES:
+		case ACTION_TRIACONTA:
+		case ACTION_STAR:
+		case ACTION_PYRAMID:
+		case ACTION_BOXES:
 		case ACTION_F16:
 			hMenu = GetMenu(hWnd);
 			(void) CheckMenuItem(hMenu,
@@ -624,6 +628,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #include <Xm/Scale.h>
 #include <Xm/ToggleB.h>
 #include <Xm/List.h>
+#include <Xm/Form.h>
 #define PRINT_MESSAGE(b) PrintState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
@@ -631,16 +636,25 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #include "Threed.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "threed.t.xpm"
+#include "threed.p.xpm"
+#include "threed.s.xpm"
+#include "threed.m.xpm"
+#include "threed.l.xpm"
+#include "threed.xpm"
+#else
 #include "pixmaps/threed.t.xpm"
 #include "pixmaps/threed.p.xpm"
 #include "pixmaps/threed.s.xpm"
 #include "pixmaps/threed.m.xpm"
 #include "pixmaps/threed.l.xpm"
 #include "pixmaps/threed.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
 (((s)<=22)?(((s)<=16)?threed_t_xpm:threed_p_xpm):\
 (((s)<=24)?threed_s_xpm:threed_m_xpm)):\
-(((s)<=48)?threed_l_xpm:threed_xpm))
+(((s)<=48)?threed_l_xpm:threed_xpm)))
 #endif
 #include "pixmaps/threed.xbm"
 #define DEFINE_XBM (char *) threed_bits, threed_width, threed_height
@@ -672,6 +686,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -748,7 +763,7 @@ static void initialize(Widget w)
 #endif
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
@@ -776,10 +791,11 @@ static void makePosVisible(Widget list_w, int item_no)
 		XmNtopItemPosition, &top,
 		XmNvisibleItemCount, &visible,
 		NULL);
-	if (item_no < top)
+	if (item_no < top) {
 		XmListSetPos(list_w, item_no);
-	else if (item_no >= top + visible)
+	} else if (item_no >= top + visible) {
 		XmListSetBottomPos(list_w, item_no);
+	}
 }
 #endif
 
@@ -817,7 +833,8 @@ static void callbackThreeD(Widget w, caddr_t clientData,
 #endif
 		break;
 	case ACTION_OBJECT:
-		object = (object + 1) % numObjects;
+		if (numObjects > 0)
+			object = (object + 1) % numObjects;
 		XtVaSetValues(w, XtNobject, object, NULL);
 		XtVaGetValues(w,
 			XtNobjectName, &name,
@@ -955,25 +972,30 @@ objectResponse(Widget listItem, XtPointer clientData, XmListCallbackStruct *cbs)
 
 #if 0
 static void
-createMenu(Widget *menu, Widget rowcol, int init)
+createMenu(Widget *menu, Widget rowCol, int init)
 {
-	XmString choice, tetra, hexa, octa, dodeca, icosa, cubes, f16;
+	XmString choice, tetra, hexa, octa, dodeca, icosa,
+	XmString rhombic, triaconta, star, pyramid, cubes, f16;
 
 	choice = XmStringCreateSimple("Object:");
 	tetra = XmStringCreateSimple("Tetrahedron");
-	hexa = XmStringCreateSimple("Hexahedron");
+	hexa = XmStringCreateSimple("Cube");
 	octa = XmStringCreateSimple("Octahedron");
 	dodeca = XmStringCreateSimple("Dodecahedron");
 	icosa = XmStringCreateSimple("Icosahedron");
-	cubes = XmStringCreateSimple("Cubes");
+	cubes = XmStringCreateSimple("Boxes");
 	f16 = XmStringCreateSimple("F16");
-	*menu = XmVaCreateSimpleOptionMenu(rowcol,
+	*menu = XmVaCreateSimpleOptionMenu(rowCol,
 		"mode_menu", choice, 'M', init, object_response,
 		XmVaPUSHBUTTON, tetra, 'T', NULL, NULL,
 		XmVaPUSHBUTTON, hexa, 'H', NULL, NULL,
 		XmVaPUSHBUTTON, octa, 'O', NULL, NULL,
 		XmVaPUSHBUTTON, dodeca, 'D', NULL, NULL,
 		XmVaPUSHBUTTON, icosa, 'I', NULL, NULL,
+		XmVaPUSHBUTTON, rhombic, 'R', NULL, NULL,
+		XmVaPUSHBUTTON, triaconta, 'N', NULL, NULL,
+		XmVaPUSHBUTTON, star, 't', NULL, NULL,
+		XmVaPUSHBUTTON, pyramid, 'P', NULL, NULL,
 		XmVaPUSHBUTTON, cubes, 'C', NULL, NULL,
 		XmVaPUSHBUTTON, f16, 'F', NULL, NULL,
 		NULL);
@@ -982,6 +1004,10 @@ createMenu(Widget *menu, Widget rowcol, int init)
 	XmStringFree(octa);
 	XmStringFree(dodeca);
 	XmStringFree(icosa);
+	XmStringFree(rhombic);
+	XmStringFree(triaconta);
+	XmStringFree(star);
+	XmStringFree(pyramid);
 	XmStringFree(cubes);
 	XmStringFree(f16);
 	XtManageChild(*menu);
@@ -989,24 +1015,22 @@ createMenu(Widget *menu, Widget rowcol, int init)
 #endif
 
 static void
-createList(Widget *rowcol, char **list, int init, int num)
+createList(Widget *rowCol, char **list, int init, int num)
 {
 	XmString label;
 	XmStringTable table;
 	int i;
-
-	label = XmStringCreateSimple((char *) "Object list:");
-	(void) XtVaCreateManagedWidget("listLabel",
-		xmLabelWidgetClass, *rowcol,
-		XmNlabelString, label,
-		NULL);
-	XmStringFree(label);
-
 	table = (XmStringTable) XtMalloc (num * sizeof (XmString *));
 	for (i = 0; i < num; i++)
 		table[i] = XmStringCreateSimple(list[i]);
 
-	objectList = XmCreateScrolledList(*rowcol, (char *) "scrolledList",
+	label = XmStringCreateSimple((char *) "Object list:");
+	(void) XtVaCreateManagedWidget("listLabel",
+		xmLabelWidgetClass, *rowCol,
+		XmNlabelString, label,
+		NULL);
+	XmStringFree(label);
+	objectList = XmCreateScrolledList(*rowCol, (char *) "scrolledList",
 		NULL, 0);
 	XtVaSetValues(objectList,
 		XmNvisibleItemCount, 5,
@@ -1017,6 +1041,7 @@ createList(Widget *rowcol, char **list, int init, int num)
 	XtAddCallback(objectList, XmNbrowseSelectionCallback,
 		(XtCallbackProc) objectResponse, (XtPointer) NULL);
 	XmListSelectPos(objectList, init + 1, True);
+	makePosVisible(objectList, init + 1);
 
 	for (i = 0; i < num; i++)
 		XmStringFree(table[i]);
@@ -1033,7 +1058,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1054,7 +1079,10 @@ createHelp(Widget w, char *text, char *title)
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
-	exit(0);
+	int val = (int) value;
+
+	if (val == 0)
+		exit(0);
 }
 
 static void
@@ -1161,7 +1189,7 @@ int main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
@@ -1267,11 +1295,6 @@ int main(int argc, char **argv)
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(psiAng, XmNvalueChangedCallback,
 		(XtCallbackProc) psiSlider, (XtPointer) NULL);
-	shapeRowCol = XtVaCreateManagedWidget("shapeRowCol",
-		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 1,
-		XmNorientation, XmHORIZONTAL,
-		XmNpacking, XmPACK_COLUMN, NULL);
 	threed = XtCreateManagedWidget("threed",
 		threedWidgetClass, panel, NULL, 0);
 #else
@@ -1319,6 +1342,10 @@ int main(int argc, char **argv)
 	XtAddCallback(threed, XtNselectCallback,
 		(XtCallbackProc) callbackThreeD, (XtPointer) NULL);
 #ifdef HAVE_MOTIF
+	shapeRowCol = XtVaCreateManagedWidget("shapeRowCol",
+		xmRowColumnWidgetClass, controlPanel,
+		XmNorientation, XmHORIZONTAL,
+		NULL);
 	/*createMenu(&objectMenu, shapeRowCol, object);*/
 	createList(&shapeRowCol, list, object, number);
 	surfaceSwitch = XtVaCreateManagedWidget("Surface",
