@@ -20,76 +20,13 @@
 
 /* Driver file for Triangles */
 
-#include "file.h"
-#ifdef WINVER
-#include "TrianglesP.h"
-#define TITLE "wtriangles"
-
-static TrianglesRec widget;
-
-#ifndef SCOREPATH
-#ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
-#else
-#define SCOREPATH "c:\\WINDOWS"
-#endif
-#endif
-#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->triangles.started = b
-#else
-#include "xwin.h"
-#include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#ifdef HAVE_MOTIF
-#include <Xm/PanedW.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Label.h>
-#include <Xm/LabelG.h>
-#include <Xm/MessageB.h>
-#include <Xm/PushBG.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Scale.h>
-#ifdef MOUSEBITMAPS
-#include "pixmaps/mouse-l.xbm"
-#include "pixmaps/mouse-r.xbm"
-#endif
-#define PRINT_MESSAGE(b) printState(message, b)
-#else
-#define PRINT_MESSAGE(b) XtWarning(b)
-#endif
-#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
-#include "Triangles.h"
-#ifdef HAVE_XPM
-#include <X11/xpm.h>
-#include "pixmaps/triangles.t.xpm"
-#include "pixmaps/triangles.p.xpm"
-#include "pixmaps/triangles.s.xpm"
-#include "pixmaps/triangles.m.xpm"
-#include "pixmaps/triangles.l.xpm"
-#include "pixmaps/triangles.xpm"
-#define RESIZE_XPM(s) ((char **) ((s)<=32)?\
-(((s)<=22)?(((s)<=16)?triangles_t_xpm:triangles_p_xpm):\
-(((s)<=24)?triangles_s_xpm:triangles_m_xpm)):\
-(((s)<=48)?triangles_l_xpm:triangles_xpm))
-#endif
-#include "pixmaps/triangles.xbm"
-#define DEFINE_XBM (char *) triangles_bits, triangles_width, triangles_height
-#ifndef SCOREPATH
-#ifdef VMS
-#define SCOREPATH "SYS$LOGIN:"
-#else
-#define SCOREPATH "/var/games/xpuzzles"
-#endif
-#endif
-#endif
-
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Triangles Version 7.4\n"
+"Triangles Version 7.4.1\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
-"http://www.tux.org/~bagleyd/puzzles.html\n"
+"http://www.tux.org/~bagleyd/puzzles.html"
 };
 
 static const char optionsHelp[] = {
@@ -100,7 +37,7 @@ static const char optionsHelp[] = {
 "[-[no]sound] [-bumpSound {filename}]\n"
 "[-{font|fn} {fontname}] [-size {int}] [-base {int}]\n"
 "[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-"[-version]\n"
+"[-version]"
 };
 #endif
 
@@ -111,7 +48,7 @@ static const char descriptionHelp[] = {
 "puzzle of Sam Loyd was made soon after).   T. R. Dawson "
 "in Original Puzzles has a similar puzzle with 4 diamond-\n"
 "and 6 triangular-shaped pieces.  This puzzle is easier to "
-"solve than 15 puzzle.\n"
+"solve than 15 puzzle."
 };
 
 static const char featuresHelp[] = {
@@ -159,7 +96,7 @@ static const char featuresHelp[] = {
 "  ^\n"
 "4< >6  Left, Right\n"
 "  v\n"
-"1   3  Lower Left, Lower Right\n"
+"1   3  Lower Left, Lower Right"
 };
 
 static const char referencesHelp[] = {
@@ -168,14 +105,86 @@ static const char referencesHelp[] = {
 "pp 1, 148, 149.\n"
 "Jerry Slocum & Jack Botermans, Puzzles Old & New (How to Make "
 "and Solve Them),  University of Washington\n"
-"Press, Seattle 1987, p 126, 127.\n"
+"Press, Seattle 1987, p 126, 127."
 };
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented."
 };
 
+#include "file.h"
+#ifdef WINVER
+#include "TrianglesP.h"
+#define TITLE "wtriangles"
+
+static TrianglesRec widget;
+
+#ifndef SCOREPATH
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
+#endif
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
+#define SET_STARTED(w,b) w->triangles.started = b
+#else
+#include "xwin.h"
+#include <X11/Shell.h>
+#include <X11/cursorfont.h>
+#ifdef HAVE_MOTIF
+#include <Xm/PanedW.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Label.h>
+#include <Xm/LabelG.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
+#ifdef MOUSEBITMAPS
+#include "pixmaps/mouse-l.xbm"
+#include "pixmaps/mouse-r.xbm"
+#endif
+#define PRINT_MESSAGE(b) printState(message, b)
+#else
+#define PRINT_MESSAGE(b) XtWarning(b)
+#endif
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
+#include "Triangles.h"
+#ifdef HAVE_XPM
+#include <X11/xpm.h>
+#ifdef CONSTPIXMAPS
+#include "triangles.t.xpm"
+#include "triangles.p.xpm"
+#include "triangles.s.xpm"
+#include "triangles.m.xpm"
+#include "triangles.l.xpm"
+#include "triangles.xpm"
+#else
+#include "pixmaps/triangles.t.xpm"
+#include "pixmaps/triangles.p.xpm"
+#include "pixmaps/triangles.s.xpm"
+#include "pixmaps/triangles.m.xpm"
+#include "pixmaps/triangles.l.xpm"
+#include "pixmaps/triangles.xpm"
+#endif
+#define RESIZE_XPM(s) ((char **) (((s)<=32)?\
+(((s)<=22)?(((s)<=16)?triangles_t_xpm:triangles_p_xpm):\
+(((s)<=24)?triangles_s_xpm:triangles_m_xpm)):\
+(((s)<=48)?triangles_l_xpm:triangles_xpm)))
+#endif
+#include "pixmaps/triangles.xbm"
+#define DEFINE_XBM (char *) triangles_bits, triangles_width, triangles_height
+#ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
+#define SCOREPATH "/var/games/xpuzzles"
+#endif
+#endif
+#endif
+
 #ifndef SCOREFILE
 #define SCOREFILE "triangles.scores"
 #endif
@@ -460,7 +469,7 @@ Widget w
 		XtNscoreOnly, &scoreOnly,
 		XtNversionOnly, &versionOnly, NULL);
 	if (versionOnly) {
-		(void) printf(aboutHelp);
+		(void) printf("%s\n", aboutHelp);
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
@@ -928,6 +937,7 @@ usage(char *programName)
 			(void) fprintf(stderr, "\t");
 		(void) fprintf(stderr, "%c", (optionsHelp[i]));
 	}
+	(void) fprintf(stderr, "\n");
 	exit(1);
 }
 
@@ -1033,7 +1043,7 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
 	XtSetArg(arg[1], XmNmessageString, messageString);
@@ -1059,7 +1069,7 @@ createHelp(Widget w, char *text, char *title)
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
 
 	messageString = XmStringCreateLtoR(text, charSet);
-	(void) sprintf(titleDsp, "%s: %s\n", progDsp, title);
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
 	XtSetArg(arg[0], XmNdialogTitle, titleString);
@@ -1202,7 +1212,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
